@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301
  * USA
  */
 
@@ -47,7 +47,7 @@ GtkWindow* GOGcpApplication::GetWindow()
 	return NULL;
 }
 
-void GOGcpApplication::ToggleMenu (const string& menuname, bool active)
+void GOGcpApplication::ToggleMenu (G_GNUC_UNUSED const string& menuname, G_GNUC_UNUSED bool active)
 {
 }
 
@@ -99,7 +99,7 @@ GtkWindow * GOGcpApplication::EditDocument (GOGChemUtilsComponent *gogcu)
 	}
 }
 
-bool GOGcpApplication::GetData (GOGChemUtilsComponent *gogcu, gpointer *data, int *length, void (**clearfunc) (gpointer), gpointer *user_data)
+bool GOGcpApplication::GetData (GOGChemUtilsComponent *gogcu, gpointer *data, int *length, void (**clearfunc) (gpointer), G_GNUC_UNUSED gpointer *user_data)
 {
 	gcp::Document *doc = static_cast <gcp::Document *> (gogcu->document);
 	bool result = false;
