@@ -27,16 +27,9 @@
 
 #include <gcu/application.h>
 #include <gcu/dialog.h>
+#include <gcu/macros.h>
 #include <gcu/object.h>
-#ifdef HAVE_GO_CONF_SYNC
-#   ifdef GOFFICE_HAS_GLOBAL_HEADER
-#      include <goffice/goffice.h>
-#   else
-#	   include <goffice/app/go-conf.h>
-#   endif
-#else
-#   include <gconf/gconf-client.h>
-#endif
+#include <goffice/app/go-conf.h>
 #include <set>
 #include <string>
 #include <map>
@@ -75,6 +68,12 @@ class Document;
 struct option_data;
 typedef void (*BuildMenuCb) (GtkUIManager *UIManager);
 
+typedef enum {
+	CursorUnallowed,
+	CursorPencil,
+	CursorMax
+} CursorId;
+
 /*!\class Application gcp/application.h
 \brief GChemPaint application base class.
 
@@ -356,7 +355,6 @@ Closes all open documents and ends the application.
 @return a list of supported mime types.
 */
 	std::list<std::string> &GetSupportedMimeTypes () {return m_SupportedMimeTypes;}
-#ifdef HAVE_GO_CONF_SYNC
 /*!
 @param node the GONode which changed.
 @param name the name of the key.
@@ -365,17 +363,6 @@ Called by the framework when the configuration entry has changed to update a
 running application preferences if the system allows such callbacks.
 */
 	void OnConfigChanged (GOConfNode *node, gchar const *name);
-#else
-/*!
-@param client a GConfClient.
-@param cnxn_id the id returned by gconf_client_notify_add.
-@param entry the entry which changed.
-
-Called by the framework when the configuration entry has changed to update a
-running application preferences.
-*/
-	void OnConfigChanged (GConfClient *client, guint cnxn_id, GConfEntry *entry);
-#endif
 /*!
 @param mime_type a mime type.
 @return the list of file name extensions corresponding to the mime type.
@@ -436,6 +423,8 @@ it is pure virtual.
 */
 	virtual void OnFileNew (char const *Theme = NULL) = 0;
 
+	GdkCursor *GetCursor (CursorId id)  {return m_Cursors[id];}
+
 protected:
 /*!
 Initialize the tools box so that the selection tool is active. This method is
@@ -492,15 +481,12 @@ private:
 	int visible_windows;
 	std::list<std::string> m_SupportedMimeTypes;
 	std::list<std::string> m_WriteableMimeTypes;
-#ifdef HAVE_GO_CONF_SYNC
 	GOConfNode *m_ConfNode;
-#else
-	GConfClient *m_ConfClient;
-#endif
 	guint m_NotificationId;
 	gcu::Object *m_Dummy;
 	std::list<BuildMenuCb> m_MenuCbs;
 	std::list<option_data> m_Options;
+	GdkCursor *m_Cursors[CursorMax];
 
 GCU_RO_POINTER_PROP	(GtkStyle, Style)
 };
