@@ -463,7 +463,7 @@ void Molecule::Transform2D (Matrix2D& m, double x, double y)
 		(*i)->GetBondsNumber ())  reinterpret_cast <Atom *> (*i)->Update ();
 }
 
-Object* Molecule::GetAtomAt (double x, double y, double z)
+Object* Molecule::GetAtomAt (double x, double y, G_GNUC_UNUSED double z)
 {
 	// Make use of Bond::GetAtomAt
 	std::list<gcu::Bond*>::iterator n, end = m_Bonds.end ();
@@ -645,7 +645,7 @@ void Molecule::BuildOBMol (OBMol &Mol)
 			}
 			pBond = (Bond*) pgAtom->GetNextBond (i);
 		}
-		obAtom.SetVector ((xav - x )/ 100, (yav - y) / 100, z / 100);
+		obAtom.SetVector ((xav - x) / 100, (yav - y) / 100, z / 100);
 		Mol.AddAtom (obAtom);
 		obAtom.Clear ();
 	}
@@ -690,27 +690,25 @@ void Molecule::BuildOBMol2D (OBMol &Mol)
 		obAtom.SetAtomicNum (pgAtom->GetZ());
 		pgAtom->GetCoords (&x, &y, &z);
 		// Scans the atom bonds and change z to try conservation of stereochemistry
-		obAtom.SetVector ((xav - x )/ 100, (yav - y) / 100, 0.);
+		obAtom.SetVector ((x - xav) / 100, (yav - y) / 100, 0.);
 		Mol.AddAtom (obAtom);
 		obAtom.Clear ();
 	}
 	list<gcu::Bond*>::iterator j, endb = m_Bonds.end ();
 	int start, end, order, flag;
-	for (j = m_Bonds.begin (); j != endb; j++)
-	{
+	for (j = m_Bonds.begin (); j != endb; j++) {
 		order = (*j)->GetOrder ();
 		start = AtomTable[(*j)->GetAtom (0)->GetId ()];
 		end = AtomTable[(*j)->GetAtom (1)->GetId ()];
-		switch((*j)->GetType ())
-		{
-			case UpBondType:
-				flag = OB_WEDGE_BOND;
-				break;
-			case DownBondType:
-				flag = OB_HASH_BOND;
-				break;
-			default:
-				flag = 0;
+		switch (reinterpret_cast <Bond *> (*j)->GetType ()) {
+		case UpBondType:
+			flag = OB_WEDGE_BOND;
+			break;
+		case DownBondType:
+			flag = OB_HASH_BOND;
+			break;
+		default:
+			flag = 0;
 		}
 		Mol.AddBond (start, end, order, flag);
 	}
@@ -804,7 +802,7 @@ void Molecule::ShowWebBase (char const* uri_start, char const *uri_end)
 	((Document*) GetDocument ())->GetApplication ()->ShowURI (uri);
 }
 
-bool Molecule::OnSignal (SignalId Signal, Object *Child)
+bool Molecule::OnSignal (G_GNUC_UNUSED SignalId Signal, G_GNUC_UNUSED Object *Child)
 {
 	m_Changed = true;
 	return true;
