@@ -4,7 +4,7 @@
  * GChemPaint library
  * reactant.cc 
  *
- * Copyright (C) 2002-2010 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2008 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -23,14 +23,15 @@
  */
 
 #include "config.h"
-#include "reactant.h"
-#include "reaction-step.h"
 #include "application.h"
 #include "document.h"
+#include "reactant.h"
+#include "reaction-step.h"
 #include "text.h"
 #include "theme.h"
 #include "tool.h"
 #include "view.h"
+#include "widgetdata.h"
 #include <glib/gi18n-lib.h>
 #include <cstring>
 
@@ -171,16 +172,14 @@ void Reactant::AddStoichiometry ()
 	View *pView = pDoc->GetView ();
 	Theme *pTheme= pDoc->GetTheme ();
 	WidgetData *pData = (WidgetData*) g_object_get_data (G_OBJECT (pDoc->GetWidget ()), "data");
-	ArtDRect rect;
-	Operation *op = pDoc->GetNewOperation (GCP_MODIFY_OPERATION);
-	op->AddNode (GetGroup ()->Save (pXmlDoc), 0);
+	gccv::Rect rect;
 	pData->GetObjectBounds (this, &rect);
 	double x = rect.x0 / pTheme->GetZoomFactor ();
 	Text *text = new Text (x, GetYAlign () + pView->GetBaseLineOffset ());
 	Stoichiometry = text;
 	AddChild (text);
 	pDoc->AddObject (text);
-	gnome_canvas_update_now (GNOME_CANVAS (pData->Canvas));
+//	gnome_canvas_update_now (GNOME_CANVAS (pData->Canvas));
 	pData->GetObjectBounds (text, &rect);
 	Child->Move (rect.x1 / pTheme->GetZoomFactor () + pTheme->GetStoichiometryPadding () - x, 0.);
 	Tool *tool = pApp->GetTool ("Text");
@@ -189,16 +188,16 @@ void Reactant::AddStoichiometry ()
 	tool->OnClicked (pView, text, rect.x0 * pTheme->GetZoomFactor (), GetYAlign () * pTheme->GetZoomFactor (), 0);
 }
 
-bool Reactant::OnSignal (SignalId Signal, Object *Obj)
+bool Reactant::OnSignal (SignalId Signal, G_GNUC_UNUSED Object *Obj)
 {
 	if (Signal == OnChangedSignal) {
 		Document *pDoc = (Document*) GetDocument ();
 		Theme *pTheme= pDoc->GetTheme ();
 		WidgetData *pData = (WidgetData*) g_object_get_data (G_OBJECT (pDoc->GetWidget ()), "data");
-		ArtDRect rect;
+		gccv::Rect rect;
 		unsigned n = GetChildrenNumber ();
 		map<string, Object*>::iterator i;
-		Object *pObj, *parent = GetParent ();
+		Object *pObj;
 		if (n == 0)
 			delete this;
 		else if (n == 1) {
@@ -212,19 +211,18 @@ bool Reactant::OnSignal (SignalId Signal, Object *Obj)
 					delete this;
 				}
 			}
-			parent->EmitSignal (OnChangedSignal);
 		} else if ((n == 2) && Stoichiometry) {
 			// Just need to space the two children
-			gnome_canvas_update_now (GNOME_CANVAS (pData->Canvas));
 			pData->GetObjectBounds (Stoichiometry, &rect);
 			double x = rect.x1 / pTheme->GetZoomFactor () + pTheme->GetStoichiometryPadding ();
 			pData->GetObjectBounds (Child, &rect);
 			Child->Move (x - rect.x0 / pTheme->GetZoomFactor (), 0.);
-			PangoLayout *layout = ((TextObject*) Stoichiometry)->GetLayout ();
+// FIXME
+/*			PangoLayout *layout = ((TextObject*) Stoichiometry)->GetLayout ();
 			const char *txt = pango_layout_get_text (layout);
 			char *endptr;
 			int n = strtol (txt, &endptr, 10);
-			m_Stoich = (!*endptr)? n: 0;
+			m_Stoich = (!*endptr)? n: 0;*/
 		} else {
 			// Most probably child has been splitted
 			xmlNodePtr node = NULL;
