@@ -70,17 +70,17 @@ Reaction::~Reaction ()
 
 bool Reaction::Build (list<Object*>& Children) throw (invalid_argument)
 {
-/*	Document *pDoc = (Document*) GetDocument ();
+	Document *pDoc = (Document*) GetDocument ();
 	Theme *pTheme = pDoc->GetTheme ();
-	WidgetData  *pData= (WidgetData*)g_object_get_data(G_OBJECT(pDoc->GetWidget ()), "data");
-	map<Object*, ArtDRect> Objects;
+	WidgetData  *pData= reinterpret_cast<WidgetData *> (g_object_get_data (G_OBJECT (pDoc->GetWidget ()), "data"));
+	map<Object*, gccv::Rect> Objects;
 	list<Object*>::iterator i, end = Children.end ();
 	list<ReactionArrow*> Arrows;
 	list<Object*> Others;
 	map<double, Object*> Left, Right;
 	double x0, y0, x1, y1, x, y, xpos, ypos, l;
 	bool horiz = true;;
-	ArtDRect *rect, srect;
+	gccv::Rect *rect, srect;
 	for (i = Children.begin (); i != end; i++) {
 		// It might be better to use the objects coordinates there
 		pData->GetObjectBounds (*i, &Objects[*i]);
@@ -206,15 +206,15 @@ bool Reaction::Build (list<Object*>& Children) throw (invalid_argument)
 			step->Move (xpos - x0 / pTheme->GetZoomFactor (), ypos - y0 / pTheme->GetZoomFactor ());
 		}
 	} else
-		throw  invalid_argument (_("Error could not build a reaction\nfrom the selected objects."));*/
+		throw  invalid_argument (_("Error could not build a reaction\nfrom the selected objects."));
 	return true;
 }
 
-void Reaction::Transform2D (Matrix2D& m, double x, double y)
+void Reaction::Transform2D (G_GNUC_UNUSED Matrix2D& m, G_GNUC_UNUSED double x, G_GNUC_UNUSED double y)
 {
 }
 
-bool Reaction::OnSignal (SignalId Signal, Object *Obj)
+bool Reaction::OnSignal (SignalId Signal, G_GNUC_UNUSED Object *Obj)
 {
 	if (IsLocked ())
 		return false;
