@@ -26,12 +26,11 @@
 #define GCU_APPLICATION_H
 
 #include "dialog-owner.h"
+#include "structs.h"
 #include <map>
 #include <set>
 #include <string>
-#ifdef HAVE_GO_CONF_SYNC
 #include <goffice/app/go-conf.h>
-#endif
 #include <gtk/gtkmain.h>
 #include <gtk/gtkwindow.h>
 #include <gtk/gtkrecentmanager.h>
@@ -48,7 +47,7 @@ class Dialog;
 /*!\class Application gcu/application.h
 This class is a base class for applications. It provides some basic services.
 */
-class Application: public DialogOwner
+class Application: virtual public DialogOwner
 {
 friend class Document;
 friend class Dialog;
@@ -106,7 +105,7 @@ if they use the FileChooser.
 	
 @return true if no error occured.
 */
-	virtual bool FileProcess (const gchar* filename, const gchar* mime_type, bool bSave, GtkWindow *window, Document *pDoc = NULL)
+	virtual bool FileProcess (G_GNUC_UNUSED const gchar* filename, G_GNUC_UNUSED const gchar* mime_type, G_GNUC_UNUSED bool bSave, G_GNUC_UNUSED GtkWindow *window, G_GNUC_UNUSED Document *pDoc = NULL)
 		{return false;}
 
 /*!
@@ -196,18 +195,19 @@ This method loads a document using the appropriate gcu::Loader class
 instance.
 @return true if no error occurred.
 */
-	bool Load (std::string const &uri, const gchar *mime_type, Document* Doc);
+	ContentType Load (std::string const &uri, const gchar *mime_type, Document* Doc);
 
 /*!
 @param uri the uri to which the document should be saved.
 @param mime_type the mime type of the document.
 @param Doc the document instance which contains the data to be saved.
+@param type the type of the data to be saved (see gcu::ContentType).
 
 This method saves the document using the appropriate gcu::Loader class
 instance.
 @return true if no error occurred.
 */
-	bool Save (std::string const &uri, const gchar *mime_type, Document* Doc);
+	bool Save (std::string const &uri, const gchar *mime_type, Document const *Doc, ContentType type);
 
 /*!
 Virtual method used to create documents. Default behavior does nothing and returns NULL.
@@ -215,14 +215,13 @@ Virtual method used to create documents. Default behavior does nothing and retur
 */
 	virtual Document *CreateNewDocument () {return NULL;}
 
-#ifdef HAVE_GO_CONF_SYNC
-
 /*!
 Method used to retrieve the base configuration node.
 @return the base configuration node.
 */
 	static GOConfNode *GetConfDir ();
-#endif
+
+	std::string const &GetIconName () {return IconName;}
 
 protected:
 
@@ -243,9 +242,8 @@ private:
 	std::string HelpBrowser;
 	std::string HelpFilename;
 	std::string CurDir;
-#ifdef HAVE_GO_CONF_SYNC
+	std::string IconName;
 	static GOConfNode *m_ConfDir;
-#endif
 
 protected:
 /*!
@@ -306,6 +304,18 @@ an exported image size, but not both.
 @return the current image height used on export as a reference.
 */
 GCU_PROP (unsigned, ImageHeight)
+/*!\fn SetTransparentBackground(bool transparent)
+@param transparent whether an export image should have a transparent background.
+
+Sets the transparency of the exported image when possible.
+*/
+/*!\fn GetTransparentBackground()
+@return whether exported image have a transparent background.
+*/
+/*!\fn GetRefTransparentBackground()
+@return whether exported image have a transparent background as a reference.
+*/
+GCU_PROP (bool, TransparentBackground)
 /*!\fn GetRecentManager()
 @return the GtkRecentFileManager attached to the application.
 */
