@@ -40,7 +40,7 @@ namespace gcu
 
 Atom::Atom (): Object (AtomType)
 {
-	m_Z = 0;
+	m_Z = -1;
 	m_x = m_y = m_z = 0.0;
 	m_Charge = 0;
 }
@@ -209,12 +209,12 @@ bool Atom::Load (xmlNodePtr node)
 	return true;
 }
 
-bool Atom::LoadNode (xmlNodePtr node)
+bool Atom::LoadNode (G_GNUC_UNUSED xmlNodePtr node)
 {
 	return true;
 }
 
-bool Atom::SaveNode (xmlDocPtr xml, xmlNodePtr node) const
+bool Atom::SaveNode (G_GNUC_UNUSED xmlDocPtr xml, G_GNUC_UNUSED xmlNodePtr node) const
 {
 	return true;
 }
@@ -240,6 +240,15 @@ bool Atom::SetProperty (unsigned property, char const *value)
 		SetCoords (x, y);
 		break;
 	}
+	case GCU_PROP_X:
+		m_x = strtod (value, NULL) * GetDocument ()->GetScale ();
+		break;
+	case GCU_PROP_Y:
+		m_y = strtod (value, NULL) * GetDocument ()->GetScale ();
+		break;
+	case GCU_PROP_Z:
+		m_z = strtod (value, NULL) * GetDocument ()->GetScale ();
+		break;
 	case GCU_PROP_ID: {
 		char *Id = (*value == 'a')? g_strdup (value): g_strdup_printf ("a%s", value);
 		SetId (Id);
@@ -270,8 +279,22 @@ string Atom::GetProperty (unsigned property) const
 			res << m_x << " " << m_y;
 		break;
 	}
+	case GCU_PROP_POS3D: {
+		Document *doc = const_cast <Atom*> (this)->GetDocument ();
+		if (doc)
+			res << m_x / doc->GetScale () << " " << m_y / doc->GetScale () << " " << m_z / doc->GetScale ();
+		else
+			res << m_x << " " << m_y << " " << m_z;
+		break;
+	}
+	case GCU_PROP_ATOM_SYMBOL:
+		res << GetSymbol ();
+		break;
+	case GCU_PROP_ATOM_CHARGE:
+		res << static_cast <int> (m_Charge);
+		break;
 	default:
-			return Object::GetProperty (property);
+		return Object::GetProperty (property);
 	}
 	return res.str ();
 }
