@@ -4,7 +4,7 @@
  * Gnome Chemistry Utils
  * bond.cc 
  *
- * Copyright (C) 2001-2010 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2008 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -26,8 +26,10 @@
 #include "bond.h"
 #include "atom.h"
 #include "objprops.h"
-#include "document.h"
 #include <cmath>
+#include <sstream>
+
+using namespace std;
 
 namespace gcu
 {
@@ -62,7 +64,7 @@ Atom* Bond::GetAtom(int which) const
 	}
 }
 
-Atom* Bond::GetAtom(Atom* pAtom, int which) const
+Atom* Bond::GetAtom(Atom* pAtom, G_GNUC_UNUSED int which) const
 {
 	return (pAtom == m_Begin)? m_End: (pAtom == m_End)? m_Begin: NULL;
 }
@@ -165,11 +167,11 @@ void Bond::IncOrder(int n)
 	if (m_order > 4)  m_order %= 4;
 }
 
-void Bond::Move(double x, double y, double z)
+void Bond::Move(G_GNUC_UNUSED double x, G_GNUC_UNUSED double y, G_GNUC_UNUSED double z)
 {
 }
 
-void Bond::Transform2D(Matrix2D& m, double x, double y)
+void Bond::Transform2D(G_GNUC_UNUSED Matrix2D& m, G_GNUC_UNUSED double x, G_GNUC_UNUSED double y)
 {
 }
 
@@ -177,15 +179,17 @@ bool Bond::SetProperty (unsigned property, char const *value)
 {
 	switch (property) {
 	case GCU_PROP_ID: {
-		char *Id = g_strdup_printf ("b%s", value);
+		char *Id = (*value == 'b')? g_strdup (value): g_strdup_printf ("b%s", value);
 		SetId (Id);
 		break;
 	}
 	case GCU_PROP_BOND_BEGIN: {
 		char *tmp = (*value == 'a')? g_strdup (value): g_strdup_printf ("a%s", value);
-		if (!GetDocument ()->SetTarget (tmp, reinterpret_cast <Object **> (&m_Begin), GetParent (), this))
-			return false;
+		Object *pObject = GetParent ()->GetDescendant (tmp);
 		g_free (tmp);
+		if (!pObject || (!dynamic_cast <Atom *> (pObject)))
+			return false;
+		m_Begin = (Atom*) pObject;
 		if (m_End) {
 			m_Begin->AddBond (this);
 			m_End->AddBond (this);
@@ -194,9 +198,11 @@ bool Bond::SetProperty (unsigned property, char const *value)
 	}
 	case GCU_PROP_BOND_END: {
 		char *tmp = (*value == 'a')? g_strdup (value): g_strdup_printf ("a%s", value);
-		if (!GetDocument ()->SetTarget (tmp, reinterpret_cast <Object **> (&m_End), GetParent (), this))
-			return false;
+		Object *pObject = GetParent ()->GetDescendant (tmp);
 		g_free (tmp);
+		if (!pObject || (!dynamic_cast <Atom *> (pObject)))
+			return false;
+		m_End = (Atom*) pObject;
 		if (m_Begin) {
 			m_Begin->AddBond (this);
 			m_End->AddBond (this);
@@ -214,6 +220,25 @@ bool Bond::SetProperty (unsigned property, char const *value)
 	return  true;
 }
 
+string Bond::GetProperty (unsigned property) const
+{
+	ostringstream res;
+	switch (property) {
+	case GCU_PROP_BOND_BEGIN:
+		res << m_Begin->GetId ();
+		break;
+	case GCU_PROP_BOND_END:
+		res << m_End->GetId ();
+		break;
+	case GCU_PROP_BOND_ORDER:
+		res << static_cast <unsigned> (m_order);
+		break;
+	default:
+			return Object::GetProperty (property);
+	}
+	return res.str ();
+}
+
 void Bond::AddCycle (Cycle* pCycle)
 {
 	m_Cycles.push_back (pCycle);
@@ -298,12 +323,4 @@ bool Bond::ReplaceAtom (Atom* oldAtom, Atom* newAtom)
 	return true;
 }
 
-void Bond::OnLoaded ()
-{
-	if (m_Begin && m_End) {
-		m_Begin->AddBond (this);
-		m_End->AddBond (this);
-	}
-}
-
 }	//	namespace gcu
