@@ -32,28 +32,28 @@
 namespace gcu
 {
 
-static void on_OK (GtkWidget *widget, Dialog* pBox)
+static void on_OK (G_GNUC_UNUSED GtkWidget *widget, Dialog* pBox)
 {
 	if (pBox->Apply ())
 		pBox->Destroy ();
 }
 
-static void on_apply (GtkWidget *widget, Dialog* pBox)
+static void on_apply (G_GNUC_UNUSED GtkWidget *widget, Dialog* pBox)
 {
 	pBox->Apply ();
 }
 
-static void on_cancel (GtkWidget *widget, Dialog* pBox)
+static void on_cancel (G_GNUC_UNUSED GtkWidget *widget, Dialog* pBox)
 {
 	pBox->Destroy ();
 }
 
-static void on_help(GtkWidget *widget, Dialog* pBox)
+static void on_help(G_GNUC_UNUSED GtkWidget *widget, Dialog* pBox)
 {
 	pBox->Help();
 }
 
-static bool on_destroy (GtkWidget *widget, Dialog* pBox)
+static bool on_destroy (G_GNUC_UNUSED GtkWidget *widget, Dialog* pBox)
 {
 	delete pBox;
 	return true;
@@ -62,9 +62,11 @@ static bool on_destroy (GtkWidget *widget, Dialog* pBox)
 Dialog::Dialog (Application* App, const char* filename, const char* windowname, DialogOwner *owner, void (*extra_destroy)(gpointer), gpointer data)
 {
 	m_App = App;
-	m_Owner = NULL;
+	m_Owner = owner;
 	if (owner && !owner->AddDialog (windowname, this)) {
 		xml = NULL;
+		dialog = NULL;
+		m_extra_destroy = NULL;
 		return;
 	}
 	m_Owner = owner;
@@ -75,7 +77,7 @@ Dialog::Dialog (Application* App, const char* filename, const char* windowname,
 		m_data = data;
 		if (xml)  glade_xml_signal_autoconnect (xml);
 		dialog = GTK_WINDOW (glade_xml_get_widget(xml, windowname));
-		gtk_window_set_icon_name (dialog, App->GetName ().c_str ());
+		gtk_window_set_icon_name (dialog, App->GetIconName ().c_str ());
 		g_signal_connect (G_OBJECT (dialog), "destroy", G_CALLBACK (on_destroy), this);
 		GtkWidget* button = glade_xml_get_widget (xml, "OK");
 		if (button) g_signal_connect (G_OBJECT (button), "clicked", G_CALLBACK (on_OK), this);
@@ -90,8 +92,12 @@ Dialog::Dialog (Application* App, const char* filename, const char* windowname,
 			else
 				gtk_widget_hide (button);
 		}
-	} else
+	} else {
 		xml = NULL;
+		dialog = NULL;
+		m_extra_destroy = NULL;
+		m_windowname = "";
+	}
 }
 
 Dialog::~Dialog()
