@@ -49,28 +49,24 @@ using namespace std;
 
 namespace gcu
 {
-#ifdef HAVE_GO_CONF_SYNC
 GOConfNode *GLView::m_ConfNode = NULL;
-#else
-GConfClient *GLView::m_ConfClient = NULL;
-#endif
 guint GLView::m_NotificationId = 0;
 int GLView::nbViews = 0;
 
 // Callbacks
-static bool on_init(GtkWidget *widget, GLView* View) 
+static bool on_init(G_GNUC_UNUSED GtkWidget *widget, GLView* View) 
 {
 	View->Init ();
 	return true;
 }
 
-bool on_reshape(GtkWidget *widget, GdkEventConfigure *event, GLView* View) 
+bool on_reshape(G_GNUC_UNUSED GtkWidget *widget, G_GNUC_UNUSED GdkEventConfigure *event, GLView* View) 
 {
 	View->Reshape ();
 	return true;
 }
 
-static bool on_draw(GtkWidget *widget, GdkEventExpose *event, GLView* View) 
+static bool on_draw(G_GNUC_UNUSED GtkWidget *widget, GdkEventExpose *event, GLView* View) 
 {
 	/* Draw only last expose. */
 	if (event->count > 0) return TRUE;
@@ -79,30 +75,22 @@ static bool on_draw(GtkWidget *widget, GdkEventExpose *event, GLView* View)
 	return true;
 }
 
-static bool on_motion(GtkWidget *widget, GdkEventMotion *event, GLView* View) 
+static bool on_motion(G_GNUC_UNUSED GtkWidget *widget, GdkEventMotion *event, GLView* View) 
 {
 	View->OnMotion (event);
 	return true;
 }
 
-static bool on_pressed(GtkWidget *widget, GdkEventButton *event, GLView* View) 
+static bool on_pressed(G_GNUC_UNUSED GtkWidget *widget, GdkEventButton *event, GLView* View) 
 {
 	return View->OnPressed (event);
 }
 
-#ifdef HAVE_GO_CONF_SYNC
-static void on_config_changed (GOConfNode *node, gchar const *key, gpointer data)
+static void on_config_changed (GOConfNode *node, gchar const *key, G_GNUC_UNUSED gpointer data)
 {
 	if (!strcmp (key, ROOTDIR"off-screen-rendering"))
 		OffScreenRendering = go_conf_get_bool (node, key);
 }
-#else
-static void on_config_changed (GConfClient *client, guint cnxn_id, GConfEntry *entry, gpointer data)
-{
-	if (!strcmp (gconf_entry_get_key (entry),ROOTDIR"off-screen-rendering"))
-		OffScreenRendering = gconf_value_get_bool (gconf_entry_get_value (entry));
-}
-#endif
 
 // GLView implementation
 #define GCU_CONF_DIR_GL "gl"
@@ -131,19 +119,9 @@ GLView::GLView (GLDocument* pDoc) throw (std::runtime_error): Printable ()
 											GDK_GL_MODE_DOUBLE));
 		if (glconfig == NULL)
 			throw  runtime_error ("*** Cannot find the double-buffered visual.\n");
-#ifdef HAVE_GO_CONF_SYNC
 		m_ConfNode = go_conf_get_node (Application::GetConfDir (), GCU_CONF_DIR_GL);
-#else
-		GError *error = NULL;
-		m_ConfClient = gconf_client_get_default ();
-		gconf_client_add_dir (m_ConfClient, "/apps/gchemutils/gl", GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
-#endif
 		GCU_GCONF_GET_NO_CHECK ("off-screen-rendering", bool, OffScreenRendering, true)
-#ifdef HAVE_GO_CONF_SYNC
 		m_NotificationId = go_conf_add_monitor (m_ConfNode, "off-screen-rendering", (GOConfMonitorFunc) on_config_changed, NULL);
-#else
-		m_NotificationId = gconf_client_notify_add (m_ConfClient, "/apps/gchemutils/gl", (GConfClientNotifyFunc) on_config_changed, NULL, NULL, NULL);
-#endif
 	}
 	/* create new OpenGL widget */
 	m_pWidget = GTK_WIDGET(gtk_drawing_area_new());
@@ -185,16 +163,9 @@ GLView::~GLView ()
 {
 	nbViews--;
 	if (!nbViews) {
-#ifdef HAVE_GO_CONF_SYNC
 		go_conf_remove_monitor (m_NotificationId);
 		go_conf_free_node (m_ConfNode);
 		m_ConfNode = NULL;
-#else
-		gconf_client_notify_remove (m_ConfClient, m_NotificationId);
-		gconf_client_remove_dir (m_ConfClient, "/apps/gchemutils/gl", NULL);
-		g_object_unref (m_ConfClient);
-		m_ConfClient = NULL;
-#endif
 		m_NotificationId = 0;
 	}
 }
@@ -554,7 +525,7 @@ osmesa:
 	return pixbuf;
 }
 
-void GLView::DoPrint (GtkPrintOperation *print, GtkPrintContext *context) const
+void GLView::DoPrint (G_GNUC_UNUSED GtkPrintOperation *print, GtkPrintContext *context, G_GNUC_UNUSED int page) const
 {
 	cairo_t *cr;
 	gdouble width, height;
