@@ -28,11 +28,7 @@
 #include "macros.h"
 #include "matrix.h"
 #include "printable.h"
-#ifdef HAVE_GO_CONF_SYNC
 #include <goffice/app/go-conf.h>
-#else
-#include <gconf/gconf-client.h>
-#endif
 #include <gtk/gtkwidget.h>
 #include <map>
 #include <string>
@@ -134,10 +130,11 @@ Generates a pixbuf from the current view.
 /*!
 @param print a GtkPrintOperation.
 @param context a GtkPrintContext.
+@param page the page to print.
 
 Prints the current view at 300 dpi.
 */
-	void DoPrint (GtkPrintOperation *print, GtkPrintContext *context) const;
+	void DoPrint (GtkPrintOperation *print, GtkPrintContext *context, int page) const;
 /*!
 @return the top level GtkWindow containing the view.
 */
@@ -171,11 +168,7 @@ private:
 	Matrix m_Euler;
 	double m_Height, m_Width, m_Near, m_Far;
 	double m_Lastx, m_Lasty;
-#ifdef HAVE_GO_CONF_SYNC
 	static GOConfNode *m_ConfNode;
-#else
-	static GConfClient *m_ConfClient;
-#endif
 	static guint m_NotificationId;
 	static int nbViews;
 
