@@ -98,6 +98,7 @@ gtk_chem3d_viewer_get_type (void)
 			sizeof (GtkChem3DViewer),
 			0,              /* n_preallocs */
 			(GInstanceInitFunc) gtk_chem3d_viewer_init,
+			NULL
 		};
 
 		chem3d_viewer_type = g_type_register_static (GTK_TYPE_BIN, "GtkChem3DViewer", &chem3d_viewer_info, (GTypeFlags)0);
@@ -116,7 +117,7 @@ GtkWidget* gtk_chem3d_viewer_new (const gchar *uri)
 
 } //extern "C"
 
-static void on_size(GtkWidget *w, GtkAllocation *allocation, gpointer data)
+static void on_size(GtkWidget *w, GtkAllocation *allocation, G_GNUC_UNUSED gpointer data)
 {
 	if (GTK_BIN (w)->child && GTK_WIDGET_VISIBLE (GTK_BIN (w)->child))
 		gtk_widget_size_allocate (GTK_BIN (w)->child, allocation);
@@ -135,7 +136,7 @@ static void gtk_chem3d_viewer_finalize (GObject *obj)
 void gtk_chem3d_viewer_class_init (GtkChem3DViewerClass  *klass)
 {
 	GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
-	parent_class = (GtkBinClass*)gtk_type_class(gtk_bin_get_type());
+	parent_class = (GtkBinClass*) g_type_class_peek_parent (klass);
 	
 	gobject_class->set_property = gtk_chem3d_viewer_set_property;
 	gobject_class->get_property = gtk_chem3d_viewer_get_property;
@@ -168,7 +169,7 @@ void gtk_chem3d_viewer_init (GtkChem3DViewer *viewer)
 	gtk_widget_show (GTK_WIDGET (viewer->widget));
 	gtk_container_add (GTK_CONTAINER (viewer), viewer->widget);
 	gtk_widget_show_all (GTK_WIDGET (viewer));
-	g_signal_connect (G_OBJECT (viewer), "size_allocate", GTK_SIGNAL_FUNC (on_size), NULL);
+	g_signal_connect (G_OBJECT (viewer), "size_allocate", G_CALLBACK (on_size), NULL);
 }
 
 void gtk_chem3d_viewer_set_uri (GtkChem3DViewer * viewer, const gchar *uri)
@@ -269,7 +270,7 @@ static void gtk_chem3d_viewer_set_property (GObject *object, guint property_id,
 	gtk_chem3d_viewer_update(viewer);
 }
 
-void gtk_chem3d_viewer_print (GtkChem3DViewer * viewer, GnomePrintContext *pc, gdouble width, gdouble height)
+GdkPixbuf *gtk_chem3d_viewer_new_pixbuf (GtkChem3DViewer * viewer, guint width, guint height)
 {
-	viewer->Doc->GetView ()->Print (pc, width, height);
+	return viewer->Doc->GetView ()->BuildPixbuf (width, height);
 }
