@@ -23,11 +23,7 @@
 #ifndef GTK_SPECTRUM_VIEWER_H
 #define GTK_SPECTRUM_VIEWER_H
 
-#ifdef GOFFICE_HAS_GLOBAL_HEADER
-#   include <goffice/goffice.h>
-#else
-#   include <goffice/graph/gog-graph.h>
-#endif
+#include <goffice/graph/gog-graph.h>
 #include <gtk/gtkwidget.h>
 
 G_BEGIN_DECLS
