@@ -26,21 +26,14 @@
 #include "cmd-context.h"
 #include "document.h"
 #include "loader.h"
-#ifndef GOFFICE_HAS_GLOBAL_HEADER
-#   include <goffice/app/error-info.h>
-#   include <goffice/app/go-plugin-service.h>
-#   include <goffice/app/go-plugin-service-impl.h>
-#   include <goffice/app/go-plugin-loader-module.h>
-#endif
+#include <goffice/app/error-info.h>
+#include <goffice/app/go-plugin-service.h>
+#include <goffice/app/go-plugin-service-impl.h>
+#include <goffice/app/go-plugin-loader-module.h>
 #include <gsf/gsf-impl-utils.h>
 #include <glib/gi18n-lib.h>
 #include <cstring>
 
-#ifndef GO_TYPE_PLUGIN_SERVICE_SIMPLE
-#   define GO_TYPE_PLUGIN_SERVICE_SIMPLE GO_PLUGIN_SERVICE_SIMPLE_TYPE
-#   define GO_TYPE_PLUGIN_LOADER_MODULE GO_PLUGIN_LOADER_MODULE_TYPE
-#endif
-
 using namespace std;
 
 namespace gcu {
@@ -108,7 +101,7 @@ plugin_service_chemical_loader_read_xml (GOPluginService * service, xmlNode * tr
 }
 
 static char *
-plugin_service_chemical_loader_get_description (GOPluginService * service)
+plugin_service_chemical_loader_get_description (G_GNUC_UNUSED GOPluginService * service)
 {
 	return g_strdup (_("Chemical file loader type."));
 }
@@ -123,13 +116,13 @@ plugin_service_chemical_loader_class_init (GObjectClass *gobject_class)
 }
 
 static void
-plugin_service_chemical_loader_init (PluginServiceChemicalLoader *s)
+plugin_service_chemical_loader_init (G_GNUC_UNUSED PluginServiceChemicalLoader *s)
 {
 }
 
 GSF_CLASS (PluginServiceChemicalLoader, plugin_service_chemical_loader,
            plugin_service_chemical_loader_class_init, plugin_service_chemical_loader_init,
-           GO_TYPE_PLUGIN_SERVICE_SIMPLE)
+           GO_PLUGIN_SERVICE_SIMPLE_TYPE)
 
 Loader::Loader ()
 {
@@ -150,7 +143,7 @@ void Loader::Init ()
 	go_plugin_loader_module_register_version ("gchemutils", VERSION);
 	char *plugins_dir = g_strdup (GCU_PLUGINS_DIR);
 	GSList *dirs = g_slist_prepend (NULL, plugins_dir);
-	go_plugins_init (gcu_get_cmd_context (), NULL, NULL, dirs, true, GO_TYPE_PLUGIN_LOADER_MODULE);
+	go_plugins_init (gcu_get_cmd_context (), NULL, NULL, dirs, true, GO_PLUGIN_LOADER_MODULE_TYPE);
 	g_slist_free (dirs);
 	g_free (plugins_dir);
 	Inited = true;
@@ -218,12 +211,12 @@ void Loader::RemoveMimeType (const char *mime_type)
 		(*it).second.loader = NULL;
 }
 
-bool Loader::Read (Document *doc, GsfInput *in, char const *mime_type, IOContext *io)
+ContentType Loader::Read (G_GNUC_UNUSED Document *doc, G_GNUC_UNUSED GsfInput *in, G_GNUC_UNUSED char const *mime_type, G_GNUC_UNUSED IOContext *io)
 {
-	return false;
+	return ContentTypeUnknown;
 }
 
-bool Loader::Write (Document *doc, GsfOutput *out, char const *mime_type, IOContext *io)
+bool Loader::Write (G_GNUC_UNUSED Object *obj, G_GNUC_UNUSED GsfOutput *out, G_GNUC_UNUSED char const *mime_type, G_GNUC_UNUSED IOContext *io, G_GNUC_UNUSED ContentType type)
 {
 	return false;
 }
