@@ -44,6 +44,7 @@ Molecule::Molecule (TypeId Type): Object (Type)
 
 Molecule::Molecule (Atom* pAtom): Object (MoleculeType)
 {
+	SetParent (pAtom->GetDocument ());
 	AddAtom (pAtom);
 	Chain* pChain = new Chain (this, pAtom); //will find the cycles
 	delete pChain;
@@ -152,8 +153,9 @@ bool Molecule::operator== (Molecule const& molecule) const
 	for (ia = m_Atoms.begin ();  ia != enda; ia++)
 		atoms1[(*ia)->GetZ ()].insert (*ia);
 	enda = molecule.m_Atoms.end ();
-	for (ia = molecule.m_Atoms.begin ();  ia != enda; ia++)
+	for (ia = molecule.m_Atoms.begin ();  ia != enda; ia++){
 		atoms2[(*ia)->GetZ ()].insert (*ia);
+	}
 	if (atoms1.size () != atoms2.size ())
 		return false;
 	map<int, set<Atom*> >::iterator ib, endb = atoms1.end (), ic, endc = atoms2.end ();
@@ -232,6 +234,7 @@ Molecule *Molecule::MoleculeFromFormula (Document *Doc, Formula const &formula,
 						PendingAtoms.pop ();
 					}
 					PendingAtoms.push (atom);
+					PendingHs = 0;
 				} else if (n == 0) {
 					atom = reinterpret_cast <Atom*> (CreateObject ("atom", mol));
 					atom->SetZ (fatom->elt);
@@ -245,13 +248,13 @@ Molecule *Molecule::MoleculeFromFormula (Document *Doc, Formula const &formula,
 						PendingAtoms.pop ();
 					}
 					done = true;
-				} else
-					;
+				}
 			}
 		} else if ((fresidue = dynamic_cast <FormulaResidue *> (*i))) {
 			// get the residue molecule and duplicate it
 			map<Atom*, Atom*> Corr;
-			Molecule const *orig = fresidue->residue->GetMolecule ();
+			Residue const *residue = Doc->GetResidue (fresidue->Symbol.c_str ());
+			Molecule const *orig = residue->GetMolecule ();
 			Atom *pseudo = NULL;
 			std::list<Atom*>::const_iterator ai, aiend = orig->m_Atoms.end ();
 			for (in = 0; in < fresidue->stoich; in++) {
