@@ -24,31 +24,16 @@
 #include "application.h"
 #include "spectrumdoc.h"
 #include "spectrumview.h"
-#ifndef GOFFICE_HAS_GLOBAL_HEADER
-#   include <goffice/data/go-data-simple.h>
-#   include <goffice/graph/gog-axis.h>
-#   include <goffice/graph/gog-plot.h>
-#   include <goffice/graph/gog-series-lines.h>
-#   ifndef GOG_TYPE_SERIES_LINES
-#      define GOG_TYPE_SERIES_LINES GOG_SERIES_LINES_TYPE
-#      define GOG_TYPE_AXIS GOG_AXIS_TYPE
-#      include <goffice/graph/gog-style.h>
-#      define GOStyle GogStyle
-#      define go_styled_object_get_style gog_styled_object_get_style
-#      define GO_STYLED_OBJECT GOG_STYLED_OBJECT
-#      define GOStyledObject GogStyledObject
-#   else
-#      include <goffice/utils/go-style.h>
-#      include <goffice/utils/go-styled-object.h>
-#   endif
-#   include <goffice/math/go-fft.h>
-#   include <goffice/math/go-math.h>
-#   include <goffice/math/go-rangefunc.h>
-#   include <goffice/math/go-regression.h>
-#   include <goffice/utils/go-color.h>
-#else
-#	include "goffice-compat.h"
-#endif
+#include <goffice/data/go-data-simple.h>
+#include <goffice/graph/gog-axis.h>
+#include <goffice/graph/gog-plot.h>
+#include <goffice/graph/gog-series-lines.h>
+#include <goffice/graph/gog-style.h>
+#include <goffice/math/go-fft.h>
+#include <goffice/math/go-math.h>
+#include <goffice/math/go-rangefunc.h>
+#include <goffice/math/go-regression.h>
+#include <goffice/utils/go-color.h>
 #include <gio/gio.h>
 #include <glib/gi18n-lib.h>
 #include <cstring>
@@ -683,8 +668,8 @@ parse_line:
 		case JCAMP_PEAK_TABLE: {
 			// in that case, add drop lines ans remove the normal line
 			GogSeries *series = m_View->GetSeries ();
-			gog_object_add_by_name (GOG_OBJECT (series), "Vertical drop lines", GOG_OBJECT (g_object_new (GOG_TYPE_SERIES_LINES, NULL)));
-			GOStyle *style = go_styled_object_get_style (GO_STYLED_OBJECT (series));
+			gog_object_add_by_name (GOG_OBJECT (series), "Vertical drop lines", GOG_OBJECT (g_object_new (GOG_SERIES_LINES_TYPE, NULL)));
+			GogStyle *style = gog_styled_object_get_style (GOG_STYLED_OBJECT (series));
 			style->line.dash_type = GO_LINE_NONE;
 			style->line.auto_dash = false;
 		}
@@ -1411,6 +1396,7 @@ out:
 		g_signal_handler_unblock (m_XAxisInvertBtn, m_XAxisInvertSgn);
 	}
 	m_View->SetAxisBounds (GOG_AXIS_X, minx, maxx, invert_axis);
+	m_View->SetAxisBounds (GOG_AXIS_Y, miny, maxy, invert_axis);
 	if (hide_y_axis)
 		m_View->ShowAxis (GOG_AXIS_Y, false);
 	/* Add axes labels */
@@ -1440,7 +1426,7 @@ void SpectrumDocument::ReadDataLine (char const *data, list<double> &l)
 		case '+':
 			c = data[i++];
 			if ((c < '0' || c > '9') && c != '.') // FIXME: throw an exception
-				;
+				{;}
 			continue;
 		case '.':
 		case '0':
@@ -1571,7 +1557,7 @@ void SpectrumDocument::ReadDataLine (char const *data, list<double> &l)
 	}
 }
 
-void SpectrumDocument::DoPrint (GtkPrintOperation *print, GtkPrintContext *context) const
+void SpectrumDocument::DoPrint (G_GNUC_UNUSED GtkPrintOperation *print, GtkPrintContext *context, G_GNUC_UNUSED int page) const
 {
 	cairo_t *cr;
 	gdouble width, height;
@@ -1981,7 +1967,7 @@ double (*SpectrumDocument::GetConversionFunction (SpectrumUnitType oldu, Spectru
 void SpectrumDocument::OnShowIntegral ()
 {
 	m_IntegralVisible = !m_IntegralVisible;
-	GOStyle *style;
+	GogStyle *style;
 	if (m_IntegralVisible) {
 		if (integral < 0) {
 			integral = variables.size ();
@@ -2051,15 +2037,15 @@ void SpectrumDocument::OnShowIntegral ()
 			gog_series_set_dim (v.Series, 0, godata, NULL);
 			godata = go_data_vector_val_new (v.Values, v.NbValues, NULL);
 			gog_series_set_dim (v.Series, 1, godata, NULL);
-			GOStyledObject *axis = GO_STYLED_OBJECT (g_object_new (GOG_TYPE_AXIS, "major-tick-labeled", false, NULL));
+			GogStyledObject *axis = GOG_STYLED_OBJECT (g_object_new (GOG_AXIS_TYPE, "major-tick-labeled", false, NULL));
 			GogPlot	*plot = gog_series_get_plot (v.Series);
 			GogObject *chart = GOG_OBJECT (gog_object_get_parent (GOG_OBJECT (plot)));
 			gog_object_add_by_name (chart, "Y-Axis", GOG_OBJECT (axis));
 			gog_plot_set_axis (plot, GOG_AXIS (axis));
-			style = go_styled_object_get_style (axis);
+			style = gog_styled_object_get_style (axis);
 			style->line.auto_dash = false;
 			style->line.dash_type = GO_LINE_NONE;
-			style = go_styled_object_get_style (GO_STYLED_OBJECT (v.Series));
+			style = gog_styled_object_get_style (GOG_STYLED_OBJECT (v.Series));
 			style->line.auto_dash = false;
 			style->line.auto_color = false;
 			style->line.color = RGBA_RED;
@@ -2071,19 +2057,19 @@ void SpectrumDocument::OnShowIntegral ()
 			delete [] xn[4];
 			delete [] yb;
 		} else
-			style = go_styled_object_get_style (GO_STYLED_OBJECT (variables[integral].Series));
+			style = gog_styled_object_get_style (GOG_STYLED_OBJECT (variables[integral].Series));
 		// show the series
 		style->line.dash_type = GO_LINE_SOLID;
 		gog_object_request_update (GOG_OBJECT (variables[integral].Series));
 	} else {
 		// hide the series
-		style = go_styled_object_get_style (GO_STYLED_OBJECT (variables[integral].Series));
+		style = gog_styled_object_get_style (GOG_STYLED_OBJECT (variables[integral].Series));
 		style->line.dash_type = GO_LINE_NONE;
 		gog_object_request_update (GOG_OBJECT (variables[integral].Series));
 	}
 }
 
-void SpectrumDocument::OnTransformFID (GtkButton *btn)
+void SpectrumDocument::OnTransformFID (G_GNUC_UNUSED GtkButton *btn)
 {
 	double *re = variables[R].Values, *im = variables[I].Values;
 	unsigned n = 2;
