@@ -2,7 +2,7 @@
  * Gnome Chemisty Utils
  * chem-viewer.c 
  *
- * Copyright (C) 2005-2008
+ * Copyright (C) 2005-2008 Jean Bréfort <jean.brefort@normalesup.org>
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
  * published by the Free Software Foundation; either version 2 of the
@@ -37,9 +37,6 @@
 #include <gdk/gdkx.h>
 #include <gtk/gtkmain.h>
 #include <gtk/gtkplug.h>
-#ifdef GOFFICE_IS_0_6
-#	include <libgnomevfs/gnome-vfs.h>
-#endif
 #include <iostream>
 #include <fstream>
 #include <sstream>
@@ -59,7 +56,7 @@ public:
 	MozPaintApp ();
 	virtual ~MozPaintApp ();
 
-	void OnFileNew (char const *Theme = NULL) {}
+	void OnFileNew (G_GNUC_UNUSED char const *Theme = NULL) {}
 	GtkWindow* GetWindow() {return NULL;}
 };
 
@@ -210,7 +207,7 @@ GIOChannel *in_channel;
 map<void*, ChemComp*> components;
 
 static gboolean
-io_func (GIOChannel *source, GIOCondition condition, gpointer data)
+io_func (GIOChannel *source, G_GNUC_UNUSED GIOCondition condition, G_GNUC_UNUSED gpointer data)
 {
 	string buf, strinst;
 	void *instance;
@@ -303,12 +300,6 @@ int main (int argc, char *argv[])
 	GError *error = NULL;
 
 	gtk_init (&argc, &argv);
-#ifdef GOFFICE_IS_0_6
-	if (!gnome_vfs_init ()) {
-		cerr << "Could not initialize GnomeVFS\n" << endl;
-		return 1;
-	}
-#endif
 	libgoffice_init ();
 	go_plugins_init (NULL, NULL, NULL, NULL, TRUE, GO_PLUGIN_LOADER_MODULE_TYPE);
 	in_channel = g_io_channel_unix_new (fileno (stdin));
