@@ -25,12 +25,16 @@
 #include "config.h"
 #include "electrontool.h"
 #include <gcp/application.h>
+#include <gcp/atom.h>
 #include <gcp/document.h>
 #include <gcp/electron.h>
 #include <gcp/molecule.h>
 #include <gcp/operation.h>
 #include <gcp/settings.h>
-#include <canvas/gcp-canvas-bpath.h>
+#include <gcp/view.h>
+#include <gcp/widgetdata.h>
+#include <gccv/circle.h>
+#include <gccv/group.h>
 #include <glib/gi18n-lib.h>
 #include <cmath>
 #include <stdexcept>
@@ -72,7 +76,7 @@ bool gcpElectronTool::OnClicked ()
 	m_Pos = pAtom->GetAvailablePosition (x, y);
 	m_x = x - m_x0;
 	m_y = y - m_y0;
-	ArtDRect rect;
+	gccv::Rect rect;
 	m_pData->GetObjectBounds (m_pObject, &rect);
 	m_x0 *= m_dZoomFactor;
 	m_y0 *= m_dZoomFactor;
@@ -87,41 +91,22 @@ bool gcpElectronTool::OnClicked ()
 	if (m_bIsPair) {
 		double deltax = 3. * sin (m_dAngle);
 		double deltay = 3. * cos (m_dAngle);
-		m_pItem =  gnome_canvas_item_new (
-						m_pGroup,
-						gnome_canvas_group_get_type (),
-						NULL);
-		gnome_canvas_item_new (
-						GNOME_CANVAS_GROUP (m_pItem),
-						gnome_canvas_ellipse_get_type (),
-						"width_units", 0.0,
-						"fill_color", gcp::AddColor,
-						"x1", x + deltax - 2. ,
-						"x2", x + deltax + 2.,
-						"y1", y + deltay - 2.,
-						"y2", y + deltay + 2.,
-						NULL);
-		gnome_canvas_item_new (
-						GNOME_CANVAS_GROUP (m_pItem),
-						gnome_canvas_ellipse_get_type (),
-						"width_units", 0.0,
-						"fill_color", gcp::AddColor,
-						"x1", x - deltax - 2. ,
-						"x2", x - deltax + 2.,
-						"y1", y - deltay - 2.,
-						"y2", y - deltay + 2.,
-						NULL);
+		gccv::Group *group = new gccv::Group (m_pView->GetCanvas ());
+		m_Item = group;
+		gccv::Circle *circle = new gccv::Circle (group, x + deltax, y + deltay, 2);
+		circle->SetLineWidth (0.);
+		circle->SetLineColor (0);
+		circle->SetFillColor (gcp::AddColor);
+		circle = new gccv::Circle (group, x - deltax, y - deltay, 2);
+		circle->SetLineWidth (0.);
+		circle->SetLineColor (0);
+		circle->SetFillColor (gcp::AddColor);
 	} else {
-		m_pItem = gnome_canvas_item_new (
-						m_pGroup,
-						gnome_canvas_ellipse_get_type (),
-						"width_units", 0.0,
-						"fill_color", gcp::AddColor,
-						"x1", x - 2. ,
-						"x2", x + 2.,
-						"y1", y - 2.,
-						"y2", y + 2.,
-						NULL);
+		gccv::Circle *circle = new gccv::Circle (m_pView->GetCanvas (), x, y, 2);
+		circle->SetLineWidth (0.);
+		circle->SetLineColor (0);
+		circle->SetFillColor (gcp::AddColor);
+		m_Item = circle;
 	}
 	char tmp[32];
 	snprintf (tmp, sizeof (tmp) - 1, _("Orientation: %g"), m_dAngle * 180. / M_PI);
@@ -132,7 +117,7 @@ bool gcpElectronTool::OnClicked ()
 
 void gcpElectronTool::OnDrag ()
 {
-	if (!m_pItem)
+	if (!m_Item)
 		return;
 	int old_pos = m_Pos;
 	m_x -= m_x0;
@@ -183,29 +168,26 @@ void gcpElectronTool::OnDrag ()
 	if ((Angle == m_dAngle) && !(m_nState & GDK_SHIFT_MASK)) {
 		if (m_dDist < m_dDistMax) {
 			if (!m_bChanged) {
-				gnome_canvas_item_show (m_pItem);
+				m_Item->SetVisible (true);
 				m_bChanged = true;
 			}
 		} else {
 			if (m_bChanged) {
-				gnome_canvas_item_hide (m_pItem);
+				m_Item->SetVisible (false);
 				m_bChanged = false;
 			}
 		}
 	} else {
-		double x, y, x1, y1, x2, y2;
+		double x, y;
 		gcp::Atom *pAtom = (gcp::Atom*) m_pObject;
 		if (!(m_nState & GDK_SHIFT_MASK) && (m_dDist >= m_dDistMax) && m_bChanged) {
-			gnome_canvas_item_hide (m_pItem);
+			m_Item->SetVisible (false);
 			m_bChanged = false;
 		} else if (pAtom->GetPosition (Angle * 180. / M_PI, x, y)) {
 			m_dAngle = Angle;
-			if (m_pItem)
-			{
-				gnome_canvas_item_get_bounds (GNOME_CANVAS_ITEM (m_pItem), &x1, &y1, &x2, &y2);
-				gtk_object_destroy (GTK_OBJECT (GNOME_CANVAS_ITEM (m_pItem)));
-				gnome_canvas_request_redraw (GNOME_CANVAS (m_pWidget), (int) x1, (int) y1, (int) x2, (int) y2);
-				m_pItem = NULL;
+			if (m_Item) {
+				delete m_Item;
+				m_Item = NULL;
 			}
 			if (m_nState & GDK_SHIFT_MASK) {
 				x = m_x0 + m_dDist * cos (m_dAngle);
@@ -219,41 +201,22 @@ void gcpElectronTool::OnDrag ()
 			if (m_bIsPair) {
 				double deltax = 3. * sin (m_dAngle);
 				double deltay = 3. * cos (m_dAngle);
-				m_pItem =  gnome_canvas_item_new (
-								m_pGroup,
-								gnome_canvas_group_get_type (),
-								NULL);
-				gnome_canvas_item_new (
-								GNOME_CANVAS_GROUP (m_pItem),
-								gnome_canvas_ellipse_get_type (),
-								"width_units", 0.0,
-								"fill_color", gcp::AddColor,
-								"x1", x + deltax - 2. ,
-								"x2", x + deltax + 2.,
-								"y1", y + deltay - 2.,
-								"y2", y + deltay + 2.,
-								NULL);
-				gnome_canvas_item_new (
-								GNOME_CANVAS_GROUP (m_pItem),
-								gnome_canvas_ellipse_get_type (),
-								"width_units", 0.0,
-								"fill_color", gcp::AddColor,
-								"x1", x - deltax - 2. ,
-								"x2", x - deltax + 2.,
-								"y1", y - deltay - 2.,
-								"y2", y - deltay + 2.,
-								NULL);
+				gccv::Group *group = new gccv::Group (m_pView->GetCanvas ());
+				m_Item = group;
+				gccv::Circle *circle = new gccv::Circle (group, x + deltax, y + deltay, 2);
+				circle->SetLineWidth (0.);
+				circle->SetLineColor (0);
+				circle->SetFillColor (gcp::AddColor);
+				circle = new gccv::Circle (group, x - deltax, y - deltay, 2);
+				circle->SetLineWidth (0.);
+				circle->SetLineColor (0);
+				circle->SetFillColor (gcp::AddColor);
 			} else {
-				m_pItem = gnome_canvas_item_new (
-								m_pGroup,
-								gnome_canvas_ellipse_get_type (),
-								"width_units", 0.0,
-								"fill_color", gcp::AddColor,
-								"x1", x - 2. ,
-								"x2", x + 2.,
-								"y1", y - 2.,
-								"y2", y + 2.,
-								NULL);
+				gccv::Circle *circle = new gccv::Circle (m_pView->GetCanvas (), x, y, 2);
+				circle->SetLineWidth (0.);
+				circle->SetLineColor (0);
+				circle->SetFillColor (gcp::AddColor);
+				m_Item = circle;
 			}
 			m_bChanged = true;
 		} else
