@@ -26,12 +26,15 @@
 #define GCHEMPAINT_CHAIN_TOOL_H
 
 #include <gcp/tool.h>
+#include <gccv/structs.h>
 #include <gtk/gtkspinbutton.h>
 #include <gtk/gtktogglebutton.h>
 #include <vector>
 
-class gcp::Atom;
-class gcp::Operation;
+namespace gcp {
+	class Atom;
+	class Operation;
+}
 
 class gcpChainTool: public gcp::Tool
 {
@@ -51,6 +54,7 @@ public:
 	void SetAngle (double angle);
 	void SetLength (double length);
 	char const *GetHelpTag () {return "chain";}
+	void Draw ();
 
 private:
 	void FindAtoms ();
@@ -60,8 +64,8 @@ private:
 	unsigned m_Length, m_CurPoints;
 	bool m_Positive, m_AutoNb, m_Allowed;
 	double m_dAngle, m_dMeanLength, m_BondLength;
-	vector <gcp::Atom *> m_Atoms;
-	GnomeCanvasPoints *m_Points;
+	std::vector <gcp::Atom *> m_Atoms;
+	gccv::Point *m_Points;
 	GtkSpinButton *m_LengthBtn, *m_AngleBtn, *m_NumberBtn;
 	GtkToggleButton *m_MergeBtn, *m_AutoBtn;
 	bool m_AutoDir;
