@@ -30,10 +30,12 @@
 #include <gcp/settings.h>
 #include <gcp/text.h>
 #include <gcp/theme.h>
+#include <gcp/view.h>
+#include <gcp/widgetdata.h>
 #include <gcp/window.h>
-#ifndef GOFFICE_HAS_GLOBAL_HEADER
-#   include <goffice/gtk/go-color-selector.h>
-#endif
+#include <gccv/text.h>
+#include <gccv/text-tag.h>
+#include <goffice/gtk/go-color-selector.h>
 #include <gdk/gdkkeysyms.h>
 #include <unistd.h>
 #include <cstring>
@@ -54,7 +56,7 @@ static void on_get_data (GtkClipboard *clipboard, GtkSelectionData *selection_da
 
 static void on_sel_changed (gcpTextTool *tool)
 {
-	tool->UpdateAttributeList ();
+	tool->UpdateTagsList ();
 }
 
 static bool filter_attribute (PangoAttribute *attribute, gcpTextTool *tool)
@@ -124,6 +126,7 @@ gcpTextTool::gcpTextTool (gcp::Application* App, string Id):
 	m_Rise = 0;
 	m_Color = RGBA_BLACK;
 	m_SelSignal = 0;
+	m_Position = gccv::Normalscript;
 }
 
 gcpTextTool::~gcpTextTool ()
@@ -142,7 +145,7 @@ gcpTextTool::~gcpTextTool ()
 bool gcpTextTool::OnClicked ()
 {
 	if (m_Active && ((m_pObject == NULL) || (m_pObject->GetType () != TextType) ||
-			(m_Active != g_object_get_data (G_OBJECT (m_pData->Items[m_pObject]), "text"))))
+			(static_cast <gccv::Item *> (m_Active) != dynamic_cast <gccv::ItemClient *> (m_pObject)->GetItem ())))
 		Unselect ();
 	bool create = false;
 	if (!m_pObject) {
@@ -156,19 +159,19 @@ bool gcpTextTool::OnClicked ()
 	if (m_pObject) {
 		if (m_pObject->GetType () != TextType)
 			return false;
-		m_pObject->SetSelected (m_pWidget, gcp::SelStateUpdating);
-		m_Active = GNOME_CANVAS_PANGO (g_object_get_data (G_OBJECT (m_pData->Items[m_pObject]), "text"));
-		m_pView->SetGnomeCanvasPangoActive (m_Active);
-		g_object_set (G_OBJECT (m_Active), "editing", true, NULL);
+		static_cast <gcp::Text *> (m_pObject)->SetSelected (gcp::SelStateUpdating);
+		m_Active = static_cast <gccv::Text *> (dynamic_cast <gccv::ItemClient *> (m_pObject)->GetItem ());
+		m_pView->SetTextActive (m_Active);
+		m_Active->SetEditing (true);
 		m_CurNode = ((gcp::Text*) m_pObject)->SaveSelected ();
 		m_InitNode = ((gcp::Text*) m_pObject)->SaveSelected ();
 		m_pView->GetDoc ()->GetWindow ()->ActivateActionWidget ("/MainMenu/FileMenu/SaveAsImage", false);
-		if (m_SelSignal == 0)
-			m_SelSignal = g_signal_connect_swapped (m_Active, "sel-changed", G_CALLBACK (on_sel_changed), this);
+/*		if (m_SelSignal == 0)
+			m_SelSignal = g_signal_connect_swapped (m_Active, "sel-changed", G_CALLBACK (on_sel_changed), this);*/
 		if (create)
-			BuildAttributeList ();
+			BuildTagsList ();
 		else
-			UpdateAttributeList ();
+			UpdateTagsList ();
 	}
 	return true;
 }
@@ -210,7 +213,7 @@ bool gcpTextTool::OnEvent (GdkEvent* event)
 				case GDK_i:
 					m_Style = (m_Style == PANGO_STYLE_NORMAL)? PANGO_STYLE_ITALIC: PANGO_STYLE_NORMAL;
 					SelectBestFontFace ();
-					BuildAttributeList ();
+					BuildTagsList ();
 					return true;
 				case GDK_u:
 					gtk_combo_box_set_active (m_UnderlineBox, ((m_Underline == PANGO_UNDERLINE_SINGLE)? PANGO_UNDERLINE_NONE: PANGO_UNDERLINE_SINGLE));
@@ -218,14 +221,16 @@ bool gcpTextTool::OnEvent (GdkEvent* event)
 				case GDK_b:
 					m_Weight = (m_Weight == PANGO_WEIGHT_NORMAL)? PANGO_WEIGHT_BOLD: PANGO_WEIGHT_NORMAL;
 					SelectBestFontFace ();
-					BuildAttributeList ();
+					BuildTagsList ();
 					return true;
 				case GDK_k:
 					gtk_toggle_button_set_active (m_StrikethroughBtn, !m_Strikethrough);
 					return true;
 				case GDK_plus:
 				case GDK_dead_circumflex:
-					if (m_Rise == 0) {
+					m_Position = (m_Position == gccv::Superscript)? gccv::Normalscript: gccv::Superscript;
+					BuildTagsList ();
+/*					if (m_Rise == 0) {
 						m_Size = m_Size * 2 / 3;
 						m_Rise = m_Size / PANGO_SCALE;
 					} else if (m_Rise < 0)
@@ -238,11 +243,13 @@ bool gcpTextTool::OnEvent (GdkEvent* event)
 					gtk_spin_button_set_value (m_RiseButton, m_Rise);
 					m_Rise *= PANGO_SCALE;
 					g_signal_handler_unblock (m_RiseButton, m_RiseSignal);
-					SetSizeFull (true);
+					SetSizeFull (true);*/
 					return true;
 				case GDK_equal:
 				case GDK_underscore:
-					if (m_Rise == 0) {
+					m_Position = (m_Position == gccv::Subscript)? gccv::Normalscript: gccv::Subscript;
+					BuildTagsList ();
+/*					if (m_Rise == 0) {
 						m_Size = m_Size * 2 / 3;
 						m_Rise = - m_Size / PANGO_SCALE / 2;
 					} else if (m_Rise > 0)
@@ -255,39 +262,43 @@ bool gcpTextTool::OnEvent (GdkEvent* event)
 					gtk_spin_button_set_value (m_RiseButton, m_Rise);
 					m_Rise *= PANGO_SCALE;
 					g_signal_handler_unblock (m_RiseButton, m_RiseSignal);
-					SetSizeFull (true);
+					SetSizeFull (true);*/
 					return true;
 				case GDK_space: {
-					GnomeCanvasPango* saved = m_Active;
+					gccv::Text *saved = m_Active;
 					m_Active = NULL;
-					UpdateAttributeList ();
+					UpdateTagsList ();
 					m_Active = saved;
-					BuildAttributeList ();
+					BuildTagsList ();
 					return true;
 				}
 				default:
 					break;
 				}
 			}
-			if (!g_utf8_validate (((GdkEventKey*) event)->string, -1, NULL)) {
-				gsize r, w;
-				gchar* newstr = g_locale_to_utf8 (((GdkEventKey*) event)->string, ((GdkEventKey*) event)->length, &r, &w, NULL);
-				g_free (((GdkEventKey*) event)->string);
-				((GdkEventKey*) event)->string = newstr;
-				((GdkEventKey*) event)->length = w;
-			}
-			gnome_canvas_item_grab_focus ((GnomeCanvasItem*) m_Active);
+			if (event->type == GDK_KEY_PRESS) {
+				if (!g_utf8_validate (((GdkEventKey*) event)->string, -1, NULL)) {
+					gsize r, w;
+					gchar* newstr = g_locale_to_utf8 (((GdkEventKey*) event)->string, ((GdkEventKey*) event)->length, &r, &w, NULL);
+					g_free (((GdkEventKey*) event)->string);
+					((GdkEventKey*) event)->string = newstr;
+					((GdkEventKey*) event)->length = w;
+				}
+				m_Active->OnKeyPressed (reinterpret_cast <GdkEventKey *> (event));
+/*			gnome_canvas_item_grab_focus ((GnomeCanvasItem*) m_Active);
 			GnomeCanvasItemClass* klass = GNOME_CANVAS_ITEM_CLASS (G_OBJECT_GET_CLASS (m_Active));
-			klass->event ((GnomeCanvasItem*) m_Active, event);
-			return true;
+			klass->event ((GnomeCanvasItem*) m_Active, event);*/
+				return true;
+			} else
+				return false;
 		} else if (event->type == GDK_BUTTON_PRESS) {
 			 switch (event->button.button) {
 				case 2:
 				return true;
 			}
 		} else if (event->type == GDK_MOTION_NOTIFY) {
-			GnomeCanvasItemClass* klass = GNOME_CANVAS_ITEM_CLASS (G_OBJECT_GET_CLASS (m_Active));
-			klass->event ((GnomeCanvasItem*) m_Active, event);
+/*			GnomeCanvasItemClass* klass = GNOME_CANVAS_ITEM_CLASS (G_OBJECT_GET_CLASS (m_Active));
+			klass->event ((GnomeCanvasItem*) m_Active, event);*/
 		}
 	}
 	return false;
@@ -296,7 +307,7 @@ bool gcpTextTool::OnEvent (GdkEvent* event)
 void gcpTextTool::Activate ()
 {
 	if (!m_Active)
-		UpdateAttributeList ();
+		UpdateTagsList ();
 }
 
 bool gcpTextTool::Deactivate ()
@@ -319,11 +330,11 @@ bool gcpTextTool::Unselect ()
 		g_signal_handler_disconnect (m_Active, m_SelSignal);
 		m_SelSignal = 0;
 	}
-	g_object_set (G_OBJECT (m_Active), "editing", false, NULL);
-	m_pView->SetGnomeCanvasPangoActive (NULL);
-	Object *pObj = (Object*) g_object_get_data (G_OBJECT (m_Active), "object");
-	pObj->SetSelected (m_pWidget, gcp::SelStateUnselected);
-	char const *text = pango_layout_get_text (gnome_canvas_pango_get_layout (m_Active));
+	m_pView->SetTextActive (NULL);
+	m_Active->SetEditing (false);
+	m_Active->GetClient ()->SetSelected (gcp::SelStateUnselected);
+	Object *pObj = dynamic_cast <Object *> (m_Active->GetClient ());
+	char const *text = m_Active->GetText ();
 	m_Active = NULL;
 	while (!m_UndoList.empty ()) {
 		xmlFree(m_UndoList.front ());
@@ -394,9 +405,9 @@ bool gcpTextTool::DeleteSelection ()
 	if (!text)
 		return false;
 	text->GetSelectionBounds (start, end);
-	gcp_pango_layout_replace_text (gnome_canvas_pango_get_layout (m_Active),
+/*	gcp_pango_layout_replace_text (gnome_canvas_pango_get_layout (m_Active),
 												start, end - start, "", NULL);
-	gnome_canvas_pango_set_selection_bounds (m_Active, start, start);
+	gnome_canvas_pango_set_selection_bounds (m_Active, start, start);*/
 	text->OnChanged (true);
 	return true;
 }
@@ -463,7 +474,7 @@ static bool filter_fragment (PangoAttribute *attr, struct FragState *s)
 	return false;
 }
 
-bool gcpTextTool::OnReceive (GtkClipboard *clipboard, GtkSelectionData *data, int type)
+bool gcpTextTool::OnReceive (GtkClipboard *clipboard, GtkSelectionData *data, G_GNUC_UNUSED int type)
 {
 	if (!m_Active)
 		return false;
@@ -472,7 +483,7 @@ bool gcpTextTool::OnReceive (GtkClipboard *clipboard, GtkSelectionData *data, in
 	gcp::Text *text = (gcp::Text*) g_object_get_data (G_OBJECT (m_Active), "object");
 	unsigned start, end;
 	text->GetSelectionBounds (start, end);
-	PangoLayout *layout = gnome_canvas_pango_get_layout (m_Active);
+	PangoLayout *layout = NULL; // FIXME
 	switch (*DataType) {
 		case gcp::GCP_CLIPBOARD_NATIVE: {
 			xmlDocPtr xml = xmlParseMemory ((const char*) data->data, data->length);
@@ -483,7 +494,7 @@ bool gcpTextTool::OnReceive (GtkClipboard *clipboard, GtkSelectionData *data, in
 			}
 			node = node->children;
 			if (!strcmp ((char*) node->name, "text")) {
-				gcp_pango_layout_replace_text (layout, start, end - start, "", NULL);
+//				gcp_pango_layout_replace_text (layout, start, end - start, "", NULL);
 				text->LoadSelection (node, start);
 				xmlFreeDoc (xml);
 				return true; // otherwise, we'd call OnChange(true) twice.
@@ -499,7 +510,8 @@ bool gcpTextTool::OnReceive (GtkClipboard *clipboard, GtkSelectionData *data, in
 				pango_attr_list_insert (l, attr);
 				attr = pango_attr_size_new (pTheme->GetFontSize ());
 				pango_attr_list_insert (l, attr);
-				gcp_pango_layout_replace_text (layout, start, end - start, buf.c_str (), l);
+// FIXME
+/*				gcp_pango_layout_replace_text (layout, start, end - start, buf.c_str (), l);
 				pango_attr_list_unref (l);
 				l = fragment->GetAttrList ();
 				struct FragState s;
@@ -508,7 +520,7 @@ bool gcpTextTool::OnReceive (GtkClipboard *clipboard, GtkSelectionData *data, in
 				pango_attr_list_filter (l, (PangoAttrFilterFunc) filter_fragment, &s);
 				delete fragment;
 				start += buf.length ();
-				gnome_canvas_pango_set_selection_bounds (m_Active, start, start);
+				gnome_canvas_pango_set_selection_bounds (m_Active, start, start);*/
 			} else {
 				xmlFreeDoc (xml);
 				return false;
@@ -517,21 +529,21 @@ bool gcpTextTool::OnReceive (GtkClipboard *clipboard, GtkSelectionData *data, in
 			break;
 		}
 		case gcp::GCP_CLIPBOARD_UTF8_STRING: {
-			PangoAttrList *l = pango_attr_list_new ();
-			gcp_pango_layout_replace_text (layout, start, end - start, (char const *) data->data, l);
-			pango_attr_list_unref (l);
+/*			PangoAttrList *l = pango_attr_list_new ();
+//			gcp_pango_layout_replace_text (layout, start, end - start, (char const *) data->data, l);
+			pango_attr_list_unref (l);*/
 			break;
 		}
 		case gcp::GCP_CLIPBOARD_STRING: {
-			PangoAttrList *l = pango_attr_list_new ();
+//			PangoAttrList *l = pango_attr_list_new ();
 			if (!g_utf8_validate ((const char*) data->data, data->length, NULL)) {
 				gsize r, w;
 				gchar* newstr = g_locale_to_utf8 ((const char*) data->data, data->length, &r, &w, NULL);
-				gcp_pango_layout_replace_text (layout, start, end - start, (char const *) data->data, l);
+//				gcp_pango_layout_replace_text (layout, start, end - start, (char const *) data->data, l);
 				g_free (newstr);
 			} else
-				gcp_pango_layout_replace_text (layout, start, end - start, (char const *) data->data, l);
-			pango_attr_list_unref (l);
+//				gcp_pango_layout_replace_text (layout, start, end - start, (char const *) data->data, l);
+//			pango_attr_list_unref (l);
 			break;
 		}
 	}
@@ -572,7 +584,7 @@ bool gcpTextTool::OnUndo ()
 	tmp = (char*) xmlGetProp (node, (xmlChar*) "end-sel");
 	end = (int) strtoul (tmp, NULL, 10);
 	xmlFree (tmp);
-	gnome_canvas_pango_set_selection_bounds (m_Active, start, end);
+//	gnome_canvas_pango_set_selection_bounds (m_Active, start, end);
 	m_CurNode = node;
 	return true;
 }
@@ -597,7 +609,7 @@ bool gcpTextTool::OnRedo ()
 	tmp = (char*) xmlGetProp (node, (xmlChar*) "end-sel");
 	end = (int) strtoul (tmp, NULL, 10);
 	xmlFree (tmp);
-	gnome_canvas_pango_set_selection_bounds (m_Active, start, end);
+//	gnome_canvas_pango_set_selection_bounds (m_Active, start, end);
 	m_CurNode = node;
 	return true;
 }
@@ -640,7 +652,7 @@ void gcpTextTool::OnGetData (GtkClipboard *clipboard, GtkSelectionData *selectio
 			m_pView->GetDoc ()->GetWindow ()->ActivateActionWidget ("/MainMenu/EditMenu/Paste", true);
 }
 
-void gcpTextTool::UpdateAttributeList ()
+void gcpTextTool::UpdateTagsList ()
 {
 	if (!m_FamilyList)
 		return;
@@ -656,11 +668,11 @@ void gcpTextTool::UpdateAttributeList ()
 	m_Strikethrough = false;
 	m_Color = RGBA_BLACK;
 	if (m_Active) {
-		PangoLayout *layout;
+/*		PangoLayout *layout;
 		g_object_get (m_Active, "layout", &layout, NULL);
 		PangoAttrList *l = pango_layout_get_attributes (layout);
 		if (l)
-			pango_attr_list_filter (l, (PangoAttrFilterFunc) filter_attribute, this);
+			pango_attr_list_filter (l, (PangoAttrFilterFunc) filter_attribute, this);*/
 	}
 	// select the found face
 	GtkTreeIter iter;
@@ -690,25 +702,26 @@ void gcpTextTool::UpdateAttributeList ()
 	g_signal_handler_block (m_ColorSelector, m_ForeSignal);
 	go_color_selector_set_color (m_ColorSelector, m_Color);
 	g_signal_handler_unblock (m_ColorSelector, m_ForeSignal);
-	BuildAttributeList ();
+	BuildTagsList ();
 }
 
-void gcpTextTool::BuildAttributeList ()
+void gcpTextTool::BuildTagsList ()
 {
 	if (!m_Active)
 		return;
-	PangoAttrList *l = pango_attr_list_new ();
-	pango_attr_list_insert (l, pango_attr_family_new (m_FamilyName));
-	pango_attr_list_insert (l, pango_attr_style_new (m_Style));
-	pango_attr_list_insert (l, pango_attr_weight_new (m_Weight));
-	pango_attr_list_insert (l, pango_attr_stretch_new (m_Stretch));
-	pango_attr_list_insert (l, pango_attr_variant_new (m_Variant));
-	pango_attr_list_insert (l, pango_attr_size_new (m_Size));
-	pango_attr_list_insert (l, pango_attr_underline_new (m_Underline));
-	pango_attr_list_insert (l, pango_attr_strikethrough_new (m_Strikethrough));
-	pango_attr_list_insert (l, pango_attr_rise_new (m_Rise));
-	pango_attr_list_insert (l, pango_attr_foreground_new (UINT_RGBA_R (m_Color) * 0x101, UINT_RGBA_G (m_Color) * 0x101, UINT_RGBA_B (m_Color) * 0x101));
-	gnome_canvas_pango_set_insert_attrs (m_Active, l);
+	gccv::TextTagList *l = new gccv::TextTagList ();
+	l->push_front (new gccv::FamilyTextTag (m_FamilyName));
+	l->push_front (new gccv::StyleTextTag (m_Style));
+	l->push_front (new gccv::WeightTextTag (m_Weight));
+	l->push_front (new gccv::StretchTextTag (m_Stretch));
+	l->push_front (new gccv::VariantTextTag (m_Variant));
+	l->push_front (new gccv::SizeTextTag (m_Size));
+	l->push_front (new gccv::UnderlineTextTag (m_Underline));
+	l->push_front (new gccv::StrikethroughTextTag (m_Strikethrough));
+	l->push_front (new gccv::RiseTextTag (m_Rise));
+	l->push_front (new gccv::ForegroundTextTag (m_Color));
+	l->push_front (new gccv::PositionTextTag (m_Position, m_Size));
+	m_Active->SetCurTagList (l);
 	m_Dirty = false;
 	if (m_pView)
 		gtk_window_present (m_pView->GetDoc ()->GetWindow ()->GetWindow ());
@@ -734,12 +747,12 @@ static void on_select_size (GtkTreeSelection *selection, gcpTextTool *tool)
 	tool->OnSelectSize (size * PANGO_SCALE);
 }
 
-static void on_size_activate (GtkEntry *entry, gcpTextTool *tool)
+static void on_size_activate (G_GNUC_UNUSED GtkEntry *entry, gcpTextTool *tool)
 {
 	tool->OnSizeChanged ();
 }
 
-static void on_size_focus_out (GtkEntry *entry, GdkEventFocus *event, gcpTextTool *tool)
+static void on_size_focus_out (G_GNUC_UNUSED GtkEntry *entry, G_GNUC_UNUSED GdkEventFocus *event, gcpTextTool *tool)
 {
 	tool->OnSizeChanged ();
 }
@@ -940,7 +953,7 @@ void gcpTextTool::OnSelectFamily (GtkTreeSelection *selection)
 		pango_attr_list_insert (l, pango_attr_weight_new (m_Weight));
 		pango_attr_list_insert (l, pango_attr_stretch_new (m_Stretch));
 		pango_attr_list_insert (l, pango_attr_variant_new (m_Variant));
-		gnome_canvas_pango_apply_attrs_to_selection (m_Active, l);
+//		gnome_canvas_pango_apply_attrs_to_selection (m_Active, l);
 		pango_attr_list_unref (l);
 	}
 }
@@ -960,14 +973,14 @@ void gcpTextTool::OnSelectFace (GtkTreeSelection *selection)
 	m_Variant = pango_font_description_get_variant (desc);
 	m_Stretch = pango_font_description_get_stretch (desc);
 	pango_font_description_free (desc);
-	BuildAttributeList ();
+	BuildTagsList ();
 	if (m_Active) {
 		PangoAttrList *l = pango_attr_list_new ();
 		pango_attr_list_insert (l, pango_attr_style_new (m_Style));
 		pango_attr_list_insert (l, pango_attr_weight_new (m_Weight));
 		pango_attr_list_insert (l, pango_attr_stretch_new (m_Stretch));
 		pango_attr_list_insert (l, pango_attr_variant_new (m_Variant));
-		gnome_canvas_pango_apply_attrs_to_selection (m_Active, l);
+//		gnome_canvas_pango_apply_attrs_to_selection (m_Active, l);
 		pango_attr_list_unref (l);
 	}
 }
@@ -1012,11 +1025,11 @@ void gcpTextTool::SetSizeFull (bool update_list)
 			gtk_tree_selection_unselect_all (selection);
 		g_signal_handler_unblock (selection, m_SizeSignal);
 	}
-	BuildAttributeList ();
+	BuildTagsList ();
 	if (m_Active) {
 		PangoAttrList *l = pango_attr_list_new ();
 		pango_attr_list_insert (l, pango_attr_size_new (m_Size));
-		gnome_canvas_pango_apply_attrs_to_selection (m_Active, l);
+//		gnome_canvas_pango_apply_attrs_to_selection (m_Active, l);
 		pango_attr_list_unref (l);
 	}
 }
@@ -1066,19 +1079,19 @@ void gcpTextTool::SelectBestFontFace ()
 	} while (gtk_tree_model_iter_next (GTK_TREE_MODEL (m_FaceList), &iter));
 }
 
-int gcpTextTool::GetIndex ()
+unsigned gcpTextTool::GetIndex ()
 {
-	return gnome_canvas_pango_get_cur_index (m_Active);
+	return (m_Active)? m_Active->GetCursorPosition (): 0;
 }
 
 void gcpTextTool::OnUnderlineChanged (unsigned underline)
 {
 	m_Underline = (PangoUnderline) underline;
-	BuildAttributeList ();
+	BuildTagsList ();
 	if (m_Active) {
 		PangoAttrList *l = pango_attr_list_new ();
 		pango_attr_list_insert (l, pango_attr_underline_new (m_Underline));
-		gnome_canvas_pango_apply_attrs_to_selection (m_Active, l);
+//		gnome_canvas_pango_apply_attrs_to_selection (m_Active, l);
 		pango_attr_list_unref (l);
 	}
 }
@@ -1086,11 +1099,11 @@ void gcpTextTool::OnUnderlineChanged (unsigned underline)
 void gcpTextTool::OnStriketroughToggled (bool strikethrough)
 {
 	m_Strikethrough = strikethrough;
-	BuildAttributeList ();
+	BuildTagsList ();
 	if (m_Active) {
 		PangoAttrList *l = pango_attr_list_new ();
 		pango_attr_list_insert (l, pango_attr_strikethrough_new (m_Strikethrough));
-		gnome_canvas_pango_apply_attrs_to_selection (m_Active, l);
+//		gnome_canvas_pango_apply_attrs_to_selection (m_Active, l);
 		pango_attr_list_unref (l);
 	}
 }
@@ -1098,17 +1111,17 @@ void gcpTextTool::OnStriketroughToggled (bool strikethrough)
 void gcpTextTool::OnPositionChanged (int position)
 {
 	m_Rise = position * PANGO_SCALE;
-	BuildAttributeList ();
+	BuildTagsList ();
 }
 
 void gcpTextTool::OnForeColorChanged (GOColor color)
 {
 	m_Color = color;
-	BuildAttributeList ();
+	BuildTagsList ();
 	if (m_Active) {
 		PangoAttrList *l = pango_attr_list_new ();
 		pango_attr_list_insert (l, pango_attr_foreground_new (UINT_RGBA_R (m_Color) * 0x101, UINT_RGBA_G (m_Color) * 0x101, UINT_RGBA_B (m_Color) * 0x101));
-		gnome_canvas_pango_apply_attrs_to_selection (m_Active, l);
+//		gnome_canvas_pango_apply_attrs_to_selection (m_Active, l);
 		pango_attr_list_unref (l);
 	}
 }
