@@ -18,7 +18,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301
  * USA
  */
 
@@ -32,14 +32,11 @@
 #include <gcu/chemistry.h>
 #include <goffice/goffice.h>
 #include <goffice/utils/go-file.h>
-#ifdef GOFFICE_IS_0_6
-#	include <libgnomevfs/gnome-vfs-init.h>
-#endif
 #include <gio/gio.h>
 #include <cstring>
 #include <cstdio>
 
-void cb_print_version (const gchar *option_name, const gchar *value, gpointer data, GError **error)
+void cb_print_version (G_GNUC_UNUSED const gchar *option_name, G_GNUC_UNUSED const gchar *value, G_GNUC_UNUSED gpointer data, G_GNUC_UNUSED GError **error)
 {
 	char *version = g_strconcat (_("GChem3d Viewer version: "), VERSION, NULL);
 	puts (version);
@@ -55,7 +52,7 @@ static GOptionEntry options[] =
 	{ "version", 'v', G_OPTION_FLAG_NO_ARG, G_OPTION_ARG_CALLBACK, (void*) cb_print_version, N_("Prints GChem3d Viewer version"), NULL },
 	{ "bgcolor", 'b', 0, G_OPTION_ARG_STRING, &bgcolor, N_("Background color: white, black or #rrggbb (default is black)"), NULL },
 	{ "display3d", 'd', 0, G_OPTION_ARG_STRING, &display3d, N_("How molecules are displayed; possible values are BallnStick (the default), SpaceFill, Cylinders, and Wireframe"), NULL },
-	{ NULL }
+	{ NULL, 0, 0, G_OPTION_ARG_NONE, NULL, NULL, NULL }
 };
 
 static char const *Display3DModeNames[] = {
@@ -92,12 +89,6 @@ int main(int argc, char *argv[])
 	textdomain (GETTEXT_PACKAGE);
 	gtk_init (&argc, &argv);
 	gtk_gl_init (&argc, &argv);
-#ifdef GOFFICE_IS_0_6
-	if (!gnome_vfs_init ()) {
-		printf ("Could not initialize GnomeVFS\n");
-		return 1;
-	}
-#endif
 
 	if (argc > 1 && argv[1][0] == '-') {
 		context = g_option_context_new (_(" [file]"));
