@@ -18,7 +18,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301
  * USA
  */
 
@@ -52,17 +52,17 @@ struct AtomStruct {
 	double Blue, Red, Green, Alpha;
 };
 
-static void on_add (GtkWidget *widget, gcAtomsDlg *pBox)
+static void on_add (G_GNUC_UNUSED GtkWidget *widget, gcAtomsDlg *pBox)
 {
 	pBox->AtomAdd ();
 }
 
-static void on_delete (GtkWidget *widget, gcAtomsDlg *pBox)
+static void on_delete (G_GNUC_UNUSED GtkWidget *widget, gcAtomsDlg *pBox)
 {
 	pBox->AtomDelete ();
 }
 
-static void on_delete_all (GtkWidget *widget, gcAtomsDlg *pBox)
+static void on_delete_all (G_GNUC_UNUSED GtkWidget *widget, gcAtomsDlg *pBox)
 {
 	pBox->AtomDeleteAll ();
 }
@@ -72,7 +72,7 @@ static void on_select (GtkTreeSelection *Selection, gcAtomsDlg *pBox)
 	pBox->AtomSelect (Selection);
 }
 
-static void on_element (GtkWidget *widget, guint Z, gcAtomsDlg *pBox)
+static void on_element (G_GNUC_UNUSED GtkWidget *widget, guint Z, gcAtomsDlg *pBox)
 {
 	pBox->OnElement (Z);
 }
@@ -117,12 +117,12 @@ gcAtomsDlg::gcAtomsDlg (gcApplication *App, gcDocument* pDoc): Dialog (App, GLAD
 	gtk_container_add (GTK_CONTAINER (frame), (GtkWidget *) periodic);
 	gtk_widget_show_all (frame);
 	GtkWidget *button = glade_xml_get_widget (xml, "add");
-	g_signal_connect (G_OBJECT (button), "clicked", GTK_SIGNAL_FUNC (on_add), this);
+	g_signal_connect (G_OBJECT (button), "clicked", G_CALLBACK (on_add), this);
 	DeleteBtn = glade_xml_get_widget (xml, "delete");
 	gtk_widget_set_sensitive (DeleteBtn,0);
 	g_signal_connect (G_OBJECT (DeleteBtn), "clicked", G_CALLBACK (on_delete), this);
 	DeleteAllBtn = glade_xml_get_widget (xml, "delete_all");
-	g_signal_connect (G_OBJECT (DeleteAllBtn), "clicked", GTK_SIGNAL_FUNC (on_delete_all), this);
+	g_signal_connect (G_OBJECT (DeleteAllBtn), "clicked", G_CALLBACK (on_delete_all), this);
 	AtomList = gtk_list_store_new (4, G_TYPE_STRING, G_TYPE_DOUBLE, G_TYPE_DOUBLE, G_TYPE_DOUBLE);
 	GtkTreeView *tree = (GtkTreeView *) glade_xml_get_widget (xml, "atomslist");
 	Selection = gtk_tree_view_get_selection (tree);
@@ -206,7 +206,7 @@ gcAtomsDlg::gcAtomsDlg (gcApplication *App, gcDocument* pDoc): Dialog (App, GLAD
 	RadiusMenu = (GtkComboBox*) glade_xml_get_widget (xml, "radius-menu");
 	m_RadiiSignalID = g_signal_connect (G_OBJECT (RadiusMenu), "changed", G_CALLBACK (on_radius_index_changed), this);
 	AtomR = (GtkEntry*) glade_xml_get_widget (xml, "atomr");
-	g_signal_connect (G_OBJECT (Selection), "changed", GTK_SIGNAL_FUNC (on_select), this);
+	g_signal_connect (G_OBJECT (Selection), "changed", G_CALLBACK (on_select), this);
 	ScaleBtn = (GtkSpinButton *) glade_xml_get_widget (xml, "scale-btn");
 	ApplyBtn = (GtkComboBox *) glade_xml_get_widget (xml, "apply-to-box");
 	gtk_combo_box_set_active (ApplyBtn, 1);
