@@ -18,7 +18,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301
  * USA
  */
 
@@ -43,17 +43,17 @@ struct CleavageStruct {
 	unsigned planes;
 };
 
-static void on_add(GtkWidget *widget, gcCleavagesDlg *pBox)
+static void on_add(G_GNUC_UNUSED GtkWidget *widget, gcCleavagesDlg *pBox)
 {
 	pBox->CleavageAdd();
 }
 
-static void on_delete(GtkWidget *widget, gcCleavagesDlg *pBox)
+static void on_delete(G_GNUC_UNUSED GtkWidget *widget, gcCleavagesDlg *pBox)
 {
 	pBox->CleavageDelete();
 }
 
-static void on_delete_all(GtkWidget *widget, gcCleavagesDlg *pBox)
+static void on_delete_all(G_GNUC_UNUSED GtkWidget *widget, gcCleavagesDlg *pBox)
 {
 	pBox->CleavageDeleteAll();
 }
@@ -77,12 +77,12 @@ gcCleavagesDlg::gcCleavagesDlg (gcApplication *App, gcDocument* pDoc): Dialog (A
 	}
 	m_pDoc = pDoc;
 	GtkWidget* button = glade_xml_get_widget(xml, "add");
-	g_signal_connect(G_OBJECT(button), "clicked", GTK_SIGNAL_FUNC(on_add), this);
+	g_signal_connect(G_OBJECT(button), "clicked", G_CALLBACK(on_add), this);
 	DeleteBtn = glade_xml_get_widget(xml, "delete");
 	gtk_widget_set_sensitive(DeleteBtn,0);
 	g_signal_connect(G_OBJECT(DeleteBtn), "clicked", G_CALLBACK(on_delete), this);
 	DeleteAllBtn = glade_xml_get_widget(xml, "delete_all");
-	g_signal_connect(G_OBJECT(DeleteAllBtn), "clicked", GTK_SIGNAL_FUNC(on_delete_all), this);
+	g_signal_connect(G_OBJECT(DeleteAllBtn), "clicked", G_CALLBACK(on_delete_all), this);
 	FixedBtn = GTK_TOGGLE_BUTTON(glade_xml_get_widget(xml, "fixed"));
 	GtkTreeView* tree = (GtkTreeView*)glade_xml_get_widget(xml, "cleavageslist");
 	Selection = gtk_tree_view_get_selection(tree);
@@ -151,7 +151,7 @@ gcCleavagesDlg::gcCleavagesDlg (gcApplication *App, gcDocument* pDoc): Dialog (A
 				  3, s.planes,
 				  -1);
 	}
-	g_signal_connect(G_OBJECT(Selection), "changed", GTK_SIGNAL_FUNC(on_select), this);
+	g_signal_connect(G_OBJECT(Selection), "changed", G_CALLBACK(on_select), this);
 	if (!m_Cleavages->len)gtk_widget_set_sensitive(DeleteAllBtn, false);
 }
 
