@@ -18,11 +18,11 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301
  * USA
  */
 #include <glib.h>
-#include <gconf/gconf-client.h>
+#include <goffice/app/go-conf.h>
 
 bool IsEmbedded();
 
@@ -33,8 +33,7 @@ void RemoveDocument(gcDocument* pDoc);
 bool RequestApp(gcView* pView);
 
 extern guint PrintWidth, PrintHeight, PrintResolution;
-extern guint TabPos;
 extern guint FoV;
 extern gdouble Phi, Theta, Psi;
 extern gdouble Red, Green, Blue;
-extern GConfClient *conf_client;
+extern GOConfNode *node;
