@@ -18,7 +18,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301
  * USA
  */
 
@@ -47,17 +47,17 @@ struct LineStruct {
 	bool duplicated;
 };
 
-static void on_add (GtkWidget *widget, gcLinesDlg *pBox)
+static void on_add (G_GNUC_UNUSED GtkWidget *widget, gcLinesDlg *pBox)
 {
 	pBox->LineAdd ();
 }
 
-static void on_delete (GtkWidget *widget, gcLinesDlg *pBox)
+static void on_delete (G_GNUC_UNUSED GtkWidget *widget, gcLinesDlg *pBox)
 {
 	pBox->LineDelete ();
 }
 
-static void on_delete_all (GtkWidget *widget, gcLinesDlg *pBox)
+static void on_delete_all (G_GNUC_UNUSED GtkWidget *widget, gcLinesDlg *pBox)
 {
 	pBox->LineDeleteAll ();
 }
@@ -77,17 +77,17 @@ static void on_toggled (GtkCellRendererToggle *cell, const gchar *path_string, g
 	pBox->OnToggled (cell, path_string);
 }
 
-static void on_edges_toggled (GtkToggleButton* btn, gcLinesDlg *pBox)
+static void on_edges_toggled (G_GNUC_UNUSED GtkToggleButton* btn, gcLinesDlg *pBox)
 {
 	pBox->OnToggledSpecial(edges);
 }
 
-static void on_diags_toggled (GtkToggleButton* btn, gcLinesDlg *pBox)
+static void on_diags_toggled (G_GNUC_UNUSED GtkToggleButton* btn, gcLinesDlg *pBox)
 {
 	pBox->OnToggledSpecial (diagonals);
 }
 
-static void on_medians_toggled (GtkToggleButton* btn, gcLinesDlg *pBox)
+static void on_medians_toggled (G_GNUC_UNUSED GtkToggleButton* btn, gcLinesDlg *pBox)
 {
 	pBox->OnToggledSpecial (medians);
 }
@@ -101,12 +101,12 @@ gcLinesDlg::gcLinesDlg (gcApplication *App, gcDocument* pDoc): Dialog (App, GLAD
 	}
 	m_pDoc = pDoc;
 	GtkWidget* button = glade_xml_get_widget (xml, "add");
-	g_signal_connect (G_OBJECT (button), "clicked", GTK_SIGNAL_FUNC (on_add), this);
+	g_signal_connect (G_OBJECT (button), "clicked", G_CALLBACK (on_add), this);
 	DeleteBtn = glade_xml_get_widget (xml, "delete");
 	gtk_widget_set_sensitive (DeleteBtn,0);
 	g_signal_connect (G_OBJECT (DeleteBtn), "clicked", G_CALLBACK (on_delete), this);
 	DeleteAllBtn = glade_xml_get_widget (xml, "delete_all");
-	g_signal_connect (G_OBJECT (DeleteAllBtn), "clicked", GTK_SIGNAL_FUNC (on_delete_all), this);
+	g_signal_connect (G_OBJECT (DeleteAllBtn), "clicked", G_CALLBACK (on_delete_all), this);
 	LineList = gtk_list_store_new (7, G_TYPE_DOUBLE, G_TYPE_DOUBLE, G_TYPE_DOUBLE, G_TYPE_DOUBLE, G_TYPE_DOUBLE, G_TYPE_DOUBLE, G_TYPE_BOOLEAN);
 	GtkTreeView* tree = (GtkTreeView *) glade_xml_get_widget (xml, "lineslist");
 	Selection = gtk_tree_view_get_selection (tree);
@@ -272,7 +272,7 @@ gcLinesDlg::gcLinesDlg (gcApplication *App, gcDocument* pDoc): Dialog (App, GLAD
 			break;
 		}
 	}
-	g_signal_connect (G_OBJECT (Selection), "changed", GTK_SIGNAL_FUNC (on_select), this);
+	g_signal_connect (G_OBJECT (Selection), "changed", G_CALLBACK (on_select), this);
 	if (!m_Lines->len)
 		gtk_widget_set_sensitive (DeleteAllBtn, false);
 }
@@ -477,7 +477,7 @@ void gcLinesDlg::OnEdited (GtkCellRendererText *cell, const gchar *path_string,
 	gtk_tree_path_free (path);
 }
 
-void gcLinesDlg::OnToggled (GtkCellRendererToggle *cell, const gchar *path_string)
+void gcLinesDlg::OnToggled (G_GNUC_UNUSED GtkCellRendererToggle *cell, const gchar *path_string)
 {
 	GtkTreePath *path = gtk_tree_path_new_from_string (path_string);
 	GtkTreeIter iter;
