@@ -18,7 +18,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301
  * USA
  */
 
@@ -48,7 +48,7 @@ public:
 	void OnClose ();
 	void OnProperties ();
 
-	void DoPrint (GtkPrintOperation *print, GtkPrintContext *context) const;
+	void DoPrint (GtkPrintOperation *print, GtkPrintContext *context, int page) const;
 	void SetGraph (GogGraph *graph);
 	GtkWindow *GetGtkWindow () {return GTK_WINDOW (dialog);}
 	void ClearGuru () {m_Guru = NULL;}
