@@ -18,23 +18,17 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301
  * USA
  */
 
 #include "config.h"
 #include "gchemtable-app.h"
-#ifndef GOFFICE_HAS_GLOBAL_HEADER
-#   include <goffice/goffice.h>
-#   include <goffice/app/go-plugin.h>
-#   include <goffice/app/go-plugin-loader-module.h>
-#endif
+#include <goffice/goffice.h>
+#include <goffice/app/go-plugin.h>
+#include <goffice/app/go-plugin-loader-module.h>
 #include <libintl.h>
 
-#ifndef GO_TYPE_PLUGIN_LOADER_MODULE
-#   define GO_TYPE_PLUGIN_LOADER_MODULE GO_PLUGIN_LOADER_MODULE_TYPE
-#endif
-
 using namespace gcu;
 
 int main (int argc, char *argv[])
@@ -47,7 +41,7 @@ int main (int argc, char *argv[])
 	GSList *l = NULL;
 	l = g_slist_append (l, (void *) "GOffice_plot_xy");
 	l = g_slist_append (l, (void *) "GOffice_reg_linear");
-	go_plugins_init (NULL, NULL, l, NULL, FALSE, GO_TYPE_PLUGIN_LOADER_MODULE);
+	go_plugins_init (NULL, NULL, l, NULL, FALSE, GO_PLUGIN_LOADER_MODULE_TYPE);
 	g_slist_free (l);
 
 	gtk_main();
