@@ -14,10 +14,10 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
- * USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this program; if not, write to the 
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA  02110-1301, USA.
  */
 
 #include "config.h"
@@ -26,9 +26,6 @@
 #include <glib.h>
 #include <gtk/gtk.h>
 #include <stdio.h>
-#ifdef GOFFICE_IS_0_6
-#	include <libgnomevfs/gnome-vfs.h>
-#endif
 
 /*!\file
 A simple sample of the use of the GtkChem3DViewer widget.
@@ -49,12 +46,6 @@ int main (int argc, char *argv[])
 	GtkWidget *viewer;
 	gchar* uri;
 	gtk_init (&argc, &argv);
-#ifdef GOFFICE_IS_0_6
-	if (!gnome_vfs_init ()) {
-		printf ("Could not initialize GnomeVFS\n");
-		return 1;
-	}
-#endif
 	
 	gcu_element_load_databases ("radii", NULL);
 
